@@ -44,17 +44,17 @@ class Model{
         })
     }
 
-    readOEFStatus() {
+    searchItems(itemType, searchTerm){
         var ajax_options = {
             type: 'GET',
-            url: 'api/oef',
+            url: 'api/' + itemType + "/" + searchTerm,
             accepts: 'application/json',
-            contentType: 'plain/text'
+            dataType: 'json'
         };
         var self = this;
         $.ajax(ajax_options)
         .done(function(data) {
-            self.$event_pump.trigger('model_OEFStatusReadSuccess', [data]);
+            self.$event_pump.trigger('model_searchReadSuccess', [data]);
         })
         .fail(function(xhr, textStatus, errorThrown) {
             self.$event_pump.trigger('model_error', [xhr, textStatus, errorThrown]);
@@ -134,13 +134,36 @@ class Model{
         })
     }
 
+    fetchAgent(agentId) {
+        var ajax_options = {
+            type: 'POST',
+            url: 'api/fetch-agent',
+            accepts: 'application/json',
+            contentType: 'application/json',
+            dataType: 'json',
+            data: JSON.stringify(agentId)
+        };
+        var self = this;
+        $.ajax(ajax_options)
+        .done(function(data) {
+          var element = {"type": $("#searchItemTypeSelected").html(), "combined": "localSkills"}
+            self.$event_pump.trigger('model_' + element["combined"] + 'AddSuccess', [data]);
+        })
+        .fail(function(xhr, textStatus, errorThrown) {
+            self.$event_pump.trigger('model_error', [xhr, textStatus, errorThrown]);
+        })
+    }
+
+
     removeItem(element, agentId, itemId) {
         var propertyName = element["type"] +  "_id"
         var ajax_options = {
-            type: 'DELETE',
-            url: 'api/agent/' + agentId + '/' + element["type"]+ "/" + itemId,
+            type: 'POST',
+            url: 'api/agent/' + agentId  + '/' + element["type"]+ '/remove',
             accepts: 'application/json',
-            contentType: 'plain/text'
+            contentType: 'application/json',
+            dataType: 'json',
+            data: JSON.stringify(itemId)
         };
         var self = this;
         $.ajax(ajax_options)
@@ -186,46 +209,14 @@ class Model{
             self.$event_pump.trigger('model_error', [xhr, textStatus, errorThrown]);
         })
     }
-    startOEFNode(){
-        var ajax_options = {
-            type: 'POST',
-            url: 'api/oef',
-            accepts: 'application/json',
-            contentType: 'application/json',
-            dataType: 'json',
-            data: JSON.stringify("Test dummy")
-        };
-        var self = this;
-        $.ajax(ajax_options)
-        .done(function(data) {
-            self.$event_pump.trigger('model_StartOEFNodeSuccess', [data]);
-        })
-        .fail(function(xhr, textStatus, errorThrown) {
-            self.$event_pump.trigger('model_error', [xhr, textStatus, errorThrown]);
-        })
-    }
-    stopOEFNode(){
-        var ajax_options = {
-            type: 'DELETE',
-            url: 'api/oef',
-            accepts: 'application/json',
-            contentType: 'plain/text'
-        };
-        var self = this;
-        $.ajax(ajax_options)
-        .done(function(data) {
-            self.$event_pump.trigger('model_StopOEFNodeSuccess', [data]);
-        })
-        .fail(function(xhr, textStatus, errorThrown) {
-            self.$event_pump.trigger('model_error', [xhr, textStatus, errorThrown]);
-        })
-    }
-    startAgent(agentId){
+    startAgent(agentId, runConnectionId){
         var ajax_options = {
             type: 'POST',
             url: 'api/agent/' + agentId + '/run',
             accepts: 'application/json',
-            contentType: 'plain/text'
+            contentType: 'application/json',
+            dataType: 'json',
+            data: JSON.stringify(runConnectionId)
         };
         var self = this;
         $.ajax(ajax_options)
@@ -261,18 +252,6 @@ class View{
         this.$event_pump = $('body');
 
     }
-
-    setOEFStatus(status){
-        $('#oefStatus').html(status);
-    }
-    setOEFTTY(tty){
-        $('#oefTTY').html(tty);
-        $('#oefTTY').scrollTop($('#oefTTY')[0].scrollHeight);
-    }
-    setOEFError(error){
-        $('#oefError').html(error);
-        $('#oefError').scrollTop($('#oefError')[0].scrollHeight);
-    }
     setAgentStatus(status){
         $('#agentStatus').html(status);
     }
@@ -284,6 +263,10 @@ class View{
         $('#agentError').html(error);
         $('#agentError').scrollTop($('#agentError')[0].scrollHeight);
     }
+    setSearchType(itemType){
+        $('#searchItemTypeTable').html(itemType);
+        $('#searchItemTypeSelected').html(itemType);
+    }
 
     setCreateId(tag, id) {
         $('#'+tag+'CreateId').val(id);
@@ -306,7 +289,7 @@ class View{
         // did we get a people array?
         if (tableName) {
             for (let i=0, l=data.length; i < l; i++) {
-                rows += `<tr><td class="id">${data[i].id}</td><td class="description">${data[i].description}</td></tr>`;
+                rows += `<tr><td class="id interactive">${data[i].public_id}</td><td class="description interactive">${data[i].description}</td></tr>`;
             }
             $('.' + tableName + ' table > tbody').append(rows);
         }
@@ -424,18 +407,7 @@ class Controller{
                 var tableBody = $(e.target).closest("."+ e.data.el["combined"] +"registeredTable");
                 self.clearTable(tableBody);
 
-                // make this row (and the cells in this row) grey
-                $(this).children().each(function(i) {
-                    var test = $(this);
-                    var text = test.text;
-                    var val = test.value;
-                    $(this).css("background-color", "gray");
-                })
-
-
-
-
-
+                $(this).addClass("aea_selected")
                 if (e.data.el["combined"] == "localAgents"){
                     self.refreshAgentData(id)
                 }
@@ -471,7 +443,7 @@ class Controller{
             this.$event_pump.on('model_'+ combineName + 'DeleteSuccess', {el: element}, function(e, data) {
                 self.model.readData(e.data.el);
 
-                self.refreshAgentData(data)
+                self.refreshAgentData("NONE")
                 self.handleButtonStates()
 
             });
@@ -492,12 +464,6 @@ class Controller{
             });
 
         }
-        this.$event_pump.on('model_OEFStatusReadSuccess', function(e, data) {
-            self.view.setOEFStatus("OEF Node Status: " + data["status"])
-            self.view.setOEFTTY(data["tty"])
-            self.view.setOEFError(data["error"])
-            self.handleButtonStates()
-        });
 
         this.$event_pump.on('model_AgentStatusReadSuccess', function(e, data) {
             self.view.setAgentStatus("Agent Status: " + data["status"])
@@ -506,27 +472,18 @@ class Controller{
             self.handleButtonStates()
         });
 
-
-
-
-        $('#startOEFNode').click({el: element}, function(e) {
-            e.preventDefault();
-
-            self.model.startOEFNode()
-            e.preventDefault();
-        });
-        $('#stopOEFNode').click({el: element}, function(e) {
-            e.preventDefault();
-
-            self.model.stopOEFNode()
-            e.preventDefault();
+        this.$event_pump.on('model_searchReadSuccess', function(e, data) {
+            self.view.setSearchType(data["item_type"])
+            self.view.build_table(data["search_result"], 'searchItemsTable');
+            self.handleButtonStates()
         });
 
         $('#startAgent').click({el: element}, function(e) {
             e.preventDefault();
             var agentId = $('#localAgentsSelectionId').html()
+            var connectionId = $('#runConnectionId').val()
             if (self.validateId(agentId)){
-                self.model.startAgent(agentId)
+                self.model.startAgent(agentId, connectionId)
             }
             else{
                 alert('Error: Attempting to start agent with ID: ' + agentId);
@@ -546,6 +503,81 @@ class Controller{
 
             e.preventDefault();
         });
+        $('#searchInputButton').click({el: element}, function(e) {
+            e.preventDefault();
+            var searchTerm = $('#searchInput').val()
+            if (self.validateId(searchTerm)){
+                var itemType = $("input[name='itemType']:checked").attr('id')
+                self.model.searchItems(itemType, searchTerm)
+            }
+            else{
+                alert('Error: Attempting to stop search for: ' + searchTerm);
+            }
+
+            e.preventDefault();
+        });
+
+        $('.searchItemsTable table > tbody ').on('click', 'tr', {el: element}, function(e) {
+
+            var $target = $(e.target),
+                id,
+                description;
+
+            id = $target
+                .parent()
+                .find('td.id')
+                .text();
+
+
+            self.view.setSelectedId("searchItemsTable", id);
+
+            // Select the appropriate row
+            var tableBody = $(e.target).closest(".searchItemsTableRegisteredTable");
+            self.clearTable(tableBody);
+
+            $(this).addClass("aea_selected")
+
+            self.handleButtonStates()
+        });
+
+
+        $('#searchItemsAdd').click({el: element}, function(e) {
+            var agentId = $('#localAgentsSelectionId').html();
+            var itemId = $('#searchItemsTableSelectionId').html();
+            // It doesn't matter too much what the combined name is as long as it exists
+            var itemType = {"type": $("#searchItemTypeSelected").html(), "combined": "localSkills"}
+
+            e.preventDefault();
+
+            if (self.validateId(agentId) && self.validateId(itemId) ) {
+                self.model.addItem(itemType, agentId, itemId)
+                self.view.setSelectedId("searchItemsTable", "NONE")
+                var tableBody = $(e.target).closest(".searchItemsTableRegisteredTable");
+                self.clearTable(tableBody);
+            } else {
+                alert('Error: Problem with one of the selected ids (either agent or ' + itemType);
+            }
+            e.preventDefault();
+        });
+
+        $('#searchAgentsFetch').click({el: element}, function(e) {
+            var agentId = $('#searchItemsTableSelectionId').html();
+            // It doesn't matter too much what the combined name is as long as it exists
+            var itemType = {"type": $("#searchItemTypeSelected").html(), "combined": "localSkills"}
+
+            e.preventDefault();
+
+            if (self.validateId(agentId) ) {
+                self.model.fetchAgent(agentId)
+                self.view.setSelectedId("searchItemsTable", "NONE")
+                var tableBody = $(e.target).closest(".searchItemsTableRegisteredTable");
+                self.clearTable(tableBody);
+            } else {
+                alert('Error: Problem with one of the selected ids (either agent or ' + itemType);
+            }
+            e.preventDefault();
+        });
+
 
         this.$event_pump.on('model_error', {el: element}, function(e, xhr, textStatus, errorThrown) {
             var error_msg = textStatus + ': ' + errorThrown + ' - ' + xhr.responseJSON.detail;
@@ -562,22 +594,22 @@ class Controller{
         $('#localAgentsSelectionId').on('input', function(e){
             self.handleButtonStates()
         });
+        $('#searchInput').on('input', function(e){
+            self.handleButtonStates()
+        });
 
         for (var j = 0; j < elements.length; j++) {
             $('#'+ elements[j]["combined"] + 'ScaffoldId').on('input', function(e){
                 self.handleButtonStates()});
         }
 
-        this.getOEFStatus();
         this.getAgentStatus();
 
     }
 
     clearTable (tableBody) {
        tableBody.children().each(function(i) {
-            $(this).children().each(function(i) {
-                $(this).css("background-color", "white");
-            })
+            $(this).removeClass("aea_selected")
         });
     }
 
@@ -592,12 +624,6 @@ class Controller{
                 var itemSelectionId = $('#' + elements[j]["combined"] + 'SelectionId').html();
                 var isDisabled =  !this.validateId(itemSelectionId);
                 $('#' + elements[j]["combined"] + 'Remove').prop('disabled', isDisabled);
-                if (isDisabled){
-                    $('#' + elements[j]["combined"] + 'Remove').html("Remove " + elements[j]["type"])
-                }
-                else{
-                    $('#' + elements[j]["combined"] + 'Remove').html("Remove " + itemSelectionId + " " + elements[j]["type"] + " from " + agentSelectionId + " agent")
-                }
 
                 var itemScaffoldId = $('#' + elements[j]["combined"] + 'ScaffoldId').val();
                 $('#' + elements[j]["combined"] + 'Scaffold').prop('disabled',
@@ -610,14 +636,18 @@ class Controller{
                 var itemSelectionId = $('#' + elements[j]["combined"] + 'SelectionId').html();
                 var isDisabled =  !this.validateId(itemSelectionId) || !this.validateId(agentSelectionId);
                 $('#' + elements[j]["combined"] + 'Add').prop('disabled', isDisabled);
-                if (isDisabled){
-                    $('#' + elements[j]["combined"] + 'Add').html("<< Add " + elements[j]["type"])
-                }
-                else{
-                    $('#' + elements[j]["combined"] + 'Add').html("<< Add " + itemSelectionId + " " + elements[j]["type"] + " to " + agentSelectionId + " agent")
-                }
             }
         }
+        // Search buttons
+        var searchTerm = $('#searchInput').val();
+        $('#searchInputButton').prop('disabled', !this.validateId(searchTerm));
+        var searchItem = $('#searchItemsTableSelectionId').html();
+        var itemType = $("#searchItemTypeSelected").html();
+        var isDisabled =  !this.validateId(searchItem) || !this.validateId(agentSelectionId) || (itemType == "agent");
+        $('#searchItemsAdd').prop('disabled', isDisabled);
+
+        var isDisabled =  !this.validateId(searchItem) || (itemType != "agent");
+        $('#searchAgentsFetch').prop('disabled', isDisabled);
         if (agentSelectionId != "NONE"){
             $('.localItemHeading').html(agentSelectionId);
         }
@@ -625,30 +655,11 @@ class Controller{
             $('.localItemHeading').html("Local");
 
         }
-
-        var isOEFStopped = $('#oefStatus').html().includes("NOT_STARTED")
-        $('#startOEFNode').prop('disabled',!isOEFStopped);
-        $('#stopOEFNode').prop('disabled', isOEFStopped);
-
-        var agentOEFStopped = $('#agentStatus').html().includes("NOT_STARTED")
-        var hasValidAgent = this.validateId(agentSelectionId);
-        $('#startAgent').prop('disabled', !hasValidAgent || !agentOEFStopped);
-        $('#stopAgent').prop('disabled', !hasValidAgent || agentOEFStopped);
-
-
-    }
-
-    getOEFStatus(){
-        this.model.readOEFStatus()
-        self = this
-        setTimeout(function() {
-            self.getOEFStatus()
-        }, 500)
-
     }
 
     getAgentStatus(){
         var agentId = $('#localAgentsSelectionId').html()
+        self = this
         if (self.validateId(agentId)){
             this.model.readAgentStatus(agentId)
         }
@@ -657,7 +668,6 @@ class Controller{
             self.view.setAgentTTY("<br><br><br><br><br>")
             self.view.setAgentError("<br><br><br><br><br>")
         }
-        self = this
         setTimeout(function() {
             self.getAgentStatus()
         }, 500)
