@@ -16,7 +16,6 @@
 #   limitations under the License.
 #
 # ------------------------------------------------------------------------------
-
 """This module contains the implementation of runtime for economic agent (AEA)."""
 
 import asyncio
@@ -25,14 +24,14 @@ from abc import ABC, abstractmethod
 from asyncio.events import AbstractEventLoop
 from contextlib import suppress
 from enum import Enum
-from typing import Optional, TYPE_CHECKING, cast
+from typing import Dict, Optional, Type, cast
 
-from aea.agent_loop import AsyncState
+from aea.abstract_agent import AbstractAgent
+from aea.agent_loop import AsyncAgentLoop, AsyncState, BaseAgentLoop, SyncAgentLoop
+from aea.decision_maker.base import DecisionMaker, DecisionMakerHandler
 from aea.helpers.async_utils import ensure_loop
-from aea.multiplexer import AsyncMultiplexer
-
-if TYPE_CHECKING:  # pragma: nocover
-    from aea.agent import Agent
+from aea.multiplexer import AsyncMultiplexer, Multiplexer
+from aea.skills.tasks import TaskManager
 
 
 logger = logging.getLogger(__name__)
@@ -51,25 +50,108 @@ class RuntimeStates(Enum):
 class BaseRuntime(ABC):
     """Abstract runtime class to create implementations."""
 
+    RUN_LOOPS: Dict[str, Type[BaseAgentLoop]] = {
+        "async": AsyncAgentLoop,
+        "sync": SyncAgentLoop,
+    }
+    DEFAULT_RUN_LOOP: str = "async"
+
     def __init__(
-        self, agent: "Agent", loop: Optional[AbstractEventLoop] = None
+        self,
+        agent: AbstractAgent,
+        loop_mode: Optional[str] = None,
+        loop: Optional[AbstractEventLoop] = None,
     ) -> None:
         """
         Init runtime.
 
         :param agent: Agent to run.
+        :param loop_mode: agent main loop mode.
         :param loop: optional event loop. if not provided a new one will be created.
         :return: None
         """
-        self._agent: "Agent" = agent
-        self._loop = ensure_loop(
-            loop
-        )  # TODO: decide who constructs loop: agent, runtime, multiplexer.
+        self._agent: AbstractAgent = agent
+        self._loop: AbstractEventLoop = ensure_loop(loop)
         self._state: AsyncState = AsyncState(RuntimeStates.stopped, RuntimeStates)
         self._state.add_callback(self._log_runtime_state)
-        self._was_started = False
+
+        self._multiplexer: Multiplexer = self._get_multiplexer_instance()
+        self._task_manager = TaskManager()
+        self._decision_maker: Optional[DecisionMaker] = None
+
+        self._loop_mode = loop_mode or self.DEFAULT_RUN_LOOP
+        self.main_loop: BaseAgentLoop = self._get_main_loop_instance(self._loop_mode)
+
+    @property
+    def loop_mode(self) -> str:  # pragma: nocover
+        """Get current loop mode."""
+        return self._loop_mode
+
+    def setup_multiplexer(self) -> None:
+        """Set up the multiplexer."""
+        setup_options = self._agent.get_multiplexer_setup_options()
+        if setup_options:
+            self.multiplexer.setup(**setup_options)
+
+    @property
+    def task_manager(self) -> TaskManager:
+        """Get the task manager."""
+        return self._task_manager
+
+    @property
+    def loop(self) -> AbstractEventLoop:
+        """Get event loop."""
+        return self._loop
+
+    @property
+    def multiplexer(self) -> Multiplexer:
+        """Get multiplexer."""
+        return self._multiplexer
+
+    def _get_multiplexer_instance(self) -> Multiplexer:
+        """Create multiplexer instance."""
+        return Multiplexer(self._agent.connections, loop=self.loop)
+
+    def _get_main_loop_class(self, loop_mode: str) -> Type[BaseAgentLoop]:
+        """
+        Get main loop class based on loop mode.
+
+        :param: loop_mode: str.
+
+        :return: MainLoop class
+        """
+        if loop_mode not in self.RUN_LOOPS:  # pragma: nocover
+            raise ValueError(
+                f"Loop `{loop_mode} is not supported. valid are: `{list(self.RUN_LOOPS.keys())}`"
+            )
+        return self.RUN_LOOPS[loop_mode]
+
+    @property
+    def decision_maker(self) -> DecisionMaker:
+        """Return decision maker if set."""
+        if self._decision_maker is None:  # pragma: nocover
+            raise ValueError("call `set_decision_maker` first!")
+        return self._decision_maker
+
+    def set_decision_maker(self, decision_maker_handler: DecisionMakerHandler) -> None:
+        """Set decision maker with handler provided."""
+        self._decision_maker = DecisionMaker(
+            decision_maker_handler=decision_maker_handler
+        )
+
+    def _get_main_loop_instance(self, loop_mode: str) -> BaseAgentLoop:
+        """
+        Construct main loop instance.
+
+        :param: loop_mode: str.
+
+        :return: AgentLoop instance
+        """
+        loop_cls = self._get_main_loop_class(loop_mode)
+        return loop_cls(self._agent)
 
     def _log_runtime_state(self, state) -> None:
+        """Log a runtime state changed."""
         logger.debug(f"[{self._agent.name}]: Runtime state changed to {state}.")
 
     def start(self) -> None:
@@ -81,7 +163,6 @@ class BaseRuntime(ABC):
                 )
             )
             return
-        self._was_started = True
         self._start()
 
     def stop(self) -> None:
@@ -99,6 +180,9 @@ class BaseRuntime(ABC):
     def _teardown(self) -> None:
         """Tear down runtime."""
         logger.debug("[{}]: Runtime teardown...".format(self._agent.name))
+        if self._decision_maker is not None:  # pragma: nocover
+            self.decision_maker.stop()
+        self.task_manager.stop()
         self._agent.teardown()
         logger.debug("[{}]: Runtime teardown completed".format(self._agent.name))
 
@@ -145,16 +229,20 @@ class AsyncRuntime(BaseRuntime):
     """Asynchronous runtime: uses asyncio loop for multiplexer and async agent main loop."""
 
     def __init__(
-        self, agent: "Agent", loop: Optional[AbstractEventLoop] = None
+        self,
+        agent: AbstractAgent,
+        loop_mode: Optional[str] = None,
+        loop: Optional[AbstractEventLoop] = None,
     ) -> None:
         """
         Init runtime.
 
         :param agent: Agent to run.
+        :param loop_mode: agent main loop mode.
         :param loop: optional event loop. if not provided a new one will be created.
         :return: None
         """
-        super().__init__(agent=agent, loop=loop)
+        super().__init__(agent=agent, loop_mode=loop_mode, loop=loop)
         self._stopping_task: Optional[asyncio.Task] = None
         self._async_stop_lock: Optional[asyncio.Lock] = None
         self._task: Optional[asyncio.Task] = None
@@ -166,8 +254,8 @@ class AsyncRuntime(BaseRuntime):
         :param loop: event loop to use.
         """
         super().set_loop(loop)
-        self._agent.multiplexer.set_loop(self._loop)
-        self._agent.main_loop.set_loop(self._loop)
+        self.multiplexer.set_loop(self.loop)
+        self.main_loop.set_loop(self.loop)
         self._async_stop_lock = asyncio.Lock()
 
     def _start(self) -> None:
@@ -178,13 +266,13 @@ class AsyncRuntime(BaseRuntime):
 
         Start runtime asynchonously in own event loop.
         """
-        self.set_loop(self._loop)
+        self.set_loop(self.loop)
 
-        logger.debug(f"Start runtime event loop {self._loop}: {id(self._loop)}")
-        self._task = self._loop.create_task(self.run_runtime())
+        logger.debug(f"Start runtime event loop {self.loop}: {id(self.loop)}")
+        self._task = self.loop.create_task(self.run_runtime())
 
         try:
-            self._loop.run_until_complete(self._task)
+            self.loop.run_until_complete(self._task)
             logger.debug("Runtime loop stopped!")
         except Exception:
             logger.exception("Exception raised during runtime processing")
@@ -208,19 +296,24 @@ class AsyncRuntime(BaseRuntime):
 
     async def _multiplexer_disconnect(self) -> None:
         """Call multiplexer disconnect asynchronous way."""
-        await AsyncMultiplexer.disconnect(self._agent.multiplexer)
+        await AsyncMultiplexer.disconnect(self.multiplexer)
 
     async def _start_multiplexer(self) -> None:
         """Call multiplexer connect asynchronous way."""
-        self._agent.setup_multiplexer()
-        await AsyncMultiplexer.connect(self._agent.multiplexer)
+        self.setup_multiplexer()
+        await AsyncMultiplexer.connect(self.multiplexer)
 
     async def _start_agent_loop(self) -> None:
         """Start agent main loop asynchronous way."""
         logger.debug("[{}]: Runtime started".format(self._agent.name))
-        self._agent.start_setup()
+        self.task_manager.start()
+        if self._decision_maker is not None:  # pragma: nocover
+            self.decision_maker.start()
+        logger.debug("[{}]: Calling setup method...".format(self._agent.name))
+        self._agent.setup()
         self._state.set(RuntimeStates.running)
-        await self._agent.main_loop.run_loop()
+        logger.debug("[{}]: Run main loop...".format(self._agent.name))
+        await self.main_loop.run_loop()
 
     async def _stop_runtime(self) -> None:
         """
@@ -243,10 +336,10 @@ class AsyncRuntime(BaseRuntime):
                     return
 
                 self._state.set(RuntimeStates.stopping)
-                self._agent.main_loop.stop()
+                self.main_loop.stop()
 
                 with suppress(BaseException):
-                    await self._agent.main_loop.wait_run_loop_stopped()
+                    await self.main_loop.wait_run_loop_stopped()
 
                 self._teardown()
 
@@ -266,21 +359,21 @@ class AsyncRuntime(BaseRuntime):
         This one calls async functions and does not guarantee to wait till runtime stopped.
         """
         logger.debug("Stop runtime coroutine.")
-        if not self._loop.is_running():  # pragma: nocover
+        if not self.loop.is_running():  # pragma: nocover
             logger.debug(
                 "Runtime event loop is not running, start loop with `stop` coroutine"
             )
 
             with suppress(BaseException):
-                self._loop.run_until_complete(asyncio.sleep(0.01))
+                self.loop.run_until_complete(asyncio.sleep(0.01))
 
-            self._loop.run_until_complete(self._stop_runtime())
+            self.loop.run_until_complete(self._stop_runtime())
             return
 
         def set_task():
-            self._stopping_task = self._loop.create_task(self._stop_runtime())
+            self._stopping_task = self.loop.create_task(self._stop_runtime())
 
-        self._loop.call_soon_threadsafe(set_task)
+        self.loop.call_soon_threadsafe(set_task)
 
 
 class ThreadedRuntime(BaseRuntime):
@@ -290,19 +383,22 @@ class ThreadedRuntime(BaseRuntime):
         """Implement runtime start function here."""
         self._state.set(RuntimeStates.starting)
 
-        self._agent.multiplexer.set_loop(asyncio.new_event_loop())
+        self.multiplexer.set_loop(asyncio.new_event_loop())
 
-        self._agent.setup_multiplexer()
-        self._agent.multiplexer.connect()
-        self._agent.start_setup()
+        self.setup_multiplexer()
+        self.multiplexer.connect()
+        self._agent.setup()
         self._start_agent_loop()
 
     def _start_agent_loop(self) -> None:
         """Start aget's main loop."""
         logger.debug("[{}]: Runtime started".format(self._agent.name))
+        self.task_manager.start()
+        if self._decision_maker is not None:  # pragma: nocover
+            self.decision_maker.start()
         try:
             self._state.set(RuntimeStates.running)
-            self._agent.main_loop.start()
+            self.main_loop.start()
             logger.debug("[{}]: Runtime stopped".format(self._agent.name))
         except KeyboardInterrupt:  # pragma: nocover
             raise
@@ -314,8 +410,8 @@ class ThreadedRuntime(BaseRuntime):
     def _stop(self) -> None:
         """Implement runtime stop function here."""
         self._state.set(RuntimeStates.stopping)
-        self._agent.main_loop.stop()
+        self.main_loop.stop()
         self._teardown()
-        self._agent.multiplexer.disconnect()
+        self.multiplexer.disconnect()
         logger.debug("[{}]: Runtime stopped".format(self._agent.name))
         self._state.set(RuntimeStates.stopped)
