@@ -31,7 +31,7 @@ class MyScaffoldBehaviour(Behaviour):
 
         :return: None
         """
-        raise NotImplementedError  # pragma: no cover
+        raise NotImplementedError
 
     def act(self) -> None:
         """
@@ -39,7 +39,7 @@ class MyScaffoldBehaviour(Behaviour):
 
         :return: None
         """
-        raise NotImplementedError  # pragma: no cover
+        raise NotImplementedError
 
     def teardown(self) -> None:
         """
@@ -47,4 +47,4 @@ class MyScaffoldBehaviour(Behaviour):
 
         :return: None
         """
-        raise NotImplementedError  # pragma: no cover
+        raise NotImplementedError
