@@ -48,7 +48,7 @@ from packages.fetchai.skills.erc1155_deploy.dialogues import (
 from packages.fetchai.skills.erc1155_deploy.strategy import Strategy
 
 
-LEDGER_API_ADDRESS = "fetchai/ledger:0.3.0"
+LEDGER_API_ADDRESS = "fetchai/ledger:0.4.0"
 
 
 class FipaHandler(Handler):
@@ -104,15 +104,13 @@ class FipaHandler(Handler):
             "unidentified dialogue for message={}.".format(fipa_msg)
         )
         default_dialogues = cast(DefaultDialogues, self.context.default_dialogues)
-        default_msg = DefaultMessage(
+        default_msg, _ = default_dialogues.create(
+            counterparty=fipa_msg.sender,
             performative=DefaultMessage.Performative.ERROR,
-            dialogue_reference=default_dialogues.new_self_initiated_dialogue_reference(),
             error_code=DefaultMessage.ErrorCode.INVALID_DIALOGUE,
             error_msg="Invalid dialogue.",
             error_data={"fipa_message": fipa_msg.encode()},
         )
-        default_msg.counterparty = fipa_msg.counterparty
-        default_dialogues.update(default_msg)
         self.context.outbox.put_message(message=default_msg)
 
     def _handle_cfp(self, fipa_msg: FipaMessage, fipa_dialogue: FipaDialogue) -> None:
@@ -127,7 +125,7 @@ class FipaHandler(Handler):
         """
         strategy = cast(Strategy, self.context.strategy)
         self.context.logger.info(
-            "received CFP from sender={}".format(fipa_msg.counterparty[-5:])
+            "received CFP from sender={}".format(fipa_msg.sender[-5:])
         )
         if not strategy.is_tokens_minted:
             self.context.logger.info("Contract items not minted yet. Try again later.")
@@ -135,18 +133,14 @@ class FipaHandler(Handler):
 
         # simply send the same proposal, independent of the query
         fipa_dialogue.proposal = strategy.get_proposal()
-        proposal_msg = FipaMessage(
-            message_id=fipa_msg.message_id + 1,
-            dialogue_reference=fipa_dialogue.dialogue_label.dialogue_reference,
-            target=fipa_msg.message_id,
+        proposal_msg = fipa_dialogue.reply(
             performative=FipaMessage.Performative.PROPOSE,
+            target_message=fipa_msg,
             proposal=fipa_dialogue.proposal,
         )
-        proposal_msg.counterparty = fipa_msg.counterparty
-        fipa_dialogue.update(proposal_msg)
         self.context.logger.info(
             "sending PROPOSE to agent={}: proposal={}".format(
-                fipa_msg.counterparty[-5:], fipa_dialogue.proposal.values,
+                fipa_msg.sender[-5:], fipa_dialogue.proposal.values,
             )
         )
         self.context.outbox.put_message(message=proposal_msg)
@@ -167,24 +161,24 @@ class FipaHandler(Handler):
         if tx_signature is not None:
             self.context.logger.info(
                 "received ACCEPT_W_INFORM from sender={}: tx_signature={}".format(
-                    fipa_msg.counterparty[-5:], tx_signature
+                    fipa_msg.sender[-5:], tx_signature
                 )
             )
             strategy = cast(Strategy, self.context.strategy)
             contract_api_dialogues = cast(
                 ContractApiDialogues, self.context.contract_api_dialogues
             )
-            contract_api_msg = ContractApiMessage(
+            contract_api_msg, contract_api_dialogue = contract_api_dialogues.create(
+                counterparty=LEDGER_API_ADDRESS,
                 performative=ContractApiMessage.Performative.GET_RAW_TRANSACTION,
-                dialogue_reference=contract_api_dialogues.new_self_initiated_dialogue_reference(),
                 ledger_id=strategy.ledger_id,
-                contract_id="fetchai/erc1155:0.8.0",
+                contract_id="fetchai/erc1155:0.9.0",
                 contract_address=strategy.contract_address,
                 callable="get_atomic_swap_single_transaction",
                 kwargs=ContractApiMessage.Kwargs(
                     {
                         "from_address": self.context.agent_address,
-                        "to_address": fipa_msg.counterparty,
+                        "to_address": fipa_msg.sender,
                         "token_id": int(fipa_dialogue.proposal.values["token_id"]),
                         "from_supply": int(
                             fipa_dialogue.proposal.values["from_supply"]
@@ -198,23 +192,16 @@ class FipaHandler(Handler):
                     }
                 ),
             )
-            contract_api_msg.counterparty = LEDGER_API_ADDRESS
-            contract_api_dialogue = cast(
-                Optional[ContractApiDialogue],
-                contract_api_dialogues.update(contract_api_msg),
-            )
-            assert (
-                contract_api_dialogue is not None
-            ), "Contract api dialogue not created."
+            contract_api_dialogue = cast(ContractApiDialogue, contract_api_dialogue)
             contract_api_dialogue.terms = strategy.get_single_swap_terms(
-                fipa_dialogue.proposal, fipa_msg.counterparty
+                fipa_dialogue.proposal, fipa_msg.sender
             )
             self.context.outbox.put_message(message=contract_api_msg)
             self.context.logger.info("requesting single atomic swap transaction...")
         else:
             self.context.logger.info(
                 "received ACCEPT_W_INFORM from sender={} with no signature.".format(
-                    fipa_msg.counterparty[-5:]
+                    fipa_msg.sender[-5:]
                 )
             )
 
@@ -266,7 +253,7 @@ class LedgerApiHandler(Handler):
 
         # handle message
         if ledger_api_msg.performative is LedgerApiMessage.Performative.BALANCE:
-            self._handle_balance(ledger_api_msg, ledger_api_dialogue)
+            self._handle_balance(ledger_api_msg)
         elif (
             ledger_api_msg.performative
             is LedgerApiMessage.Performative.TRANSACTION_DIGEST
@@ -276,7 +263,7 @@ class LedgerApiHandler(Handler):
             ledger_api_msg.performative
             is LedgerApiMessage.Performative.TRANSACTION_RECEIPT
         ):
-            self._handle_transaction_receipt(ledger_api_msg, ledger_api_dialogue)
+            self._handle_transaction_receipt(ledger_api_msg)
         elif ledger_api_msg.performative == LedgerApiMessage.Performative.ERROR:
             self._handle_error(ledger_api_msg, ledger_api_dialogue)
         else:
@@ -302,14 +289,11 @@ class LedgerApiHandler(Handler):
             )
         )
 
-    def _handle_balance(
-        self, ledger_api_msg: LedgerApiMessage, ledger_api_dialogue: LedgerApiDialogue
-    ) -> None:
+    def _handle_balance(self, ledger_api_msg: LedgerApiMessage) -> None:
         """
         Handle a message of balance performative.
 
         :param ledger_api_message: the ledger api message
-        :param ledger_api_dialogue: the ledger api dialogue
         """
         self.context.logger.info(
             "starting balance on {} ledger={}.".format(
@@ -331,26 +315,19 @@ class LedgerApiHandler(Handler):
                 ledger_api_msg.transaction_digest
             )
         )
-        msg = LedgerApiMessage(
+        msg = ledger_api_dialogue.reply(
             performative=LedgerApiMessage.Performative.GET_TRANSACTION_RECEIPT,
-            message_id=ledger_api_msg.message_id + 1,
-            dialogue_reference=ledger_api_dialogue.dialogue_label.dialogue_reference,
-            target=ledger_api_msg.message_id,
+            target_message=ledger_api_msg,
             transaction_digest=ledger_api_msg.transaction_digest,
         )
-        msg.counterparty = ledger_api_msg.counterparty
-        ledger_api_dialogue.update(msg)
         self.context.outbox.put_message(message=msg)
         self.context.logger.info("requesting transaction receipt.")
 
-    def _handle_transaction_receipt(
-        self, ledger_api_msg: LedgerApiMessage, ledger_api_dialogue: LedgerApiDialogue
-    ) -> None:
+    def _handle_transaction_receipt(self, ledger_api_msg: LedgerApiMessage) -> None:
         """
         Handle a message of transaction_receipt performative.
 
         :param ledger_api_message: the ledger api message
-        :param ledger_api_dialogue: the ledger api dialogue
         """
         is_transaction_successful = EthereumHelper.is_transaction_settled(
             ledger_api_msg.transaction_receipt.receipt
@@ -494,19 +471,13 @@ class ContractApiHandler(Handler):
         """
         self.context.logger.info("received raw transaction={}".format(contract_api_msg))
         signing_dialogues = cast(SigningDialogues, self.context.signing_dialogues)
-        signing_msg = SigningMessage(
+        signing_msg, signing_dialogue = signing_dialogues.create(
+            counterparty="decision_maker",
             performative=SigningMessage.Performative.SIGN_TRANSACTION,
-            dialogue_reference=signing_dialogues.new_self_initiated_dialogue_reference(),
-            skill_callback_ids=(str(self.context.skill_id),),
             raw_transaction=contract_api_msg.raw_transaction,
             terms=contract_api_dialogue.terms,
-            skill_callback_info={},
         )
-        signing_msg.counterparty = "decision_maker"
-        signing_dialogue = cast(
-            Optional[SigningDialogue], signing_dialogues.update(signing_msg)
-        )
-        assert signing_dialogue is not None, "Error when creating signing dialogue."
+        signing_dialogue = cast(SigningDialogue, signing_dialogue)
         signing_dialogue.associated_contract_api_dialogue = contract_api_dialogue
         self.context.decision_maker_message_queue.put_nowait(signing_msg)
         self.context.logger.info(
@@ -617,16 +588,12 @@ class SigningHandler(Handler):
         ledger_api_dialogues = cast(
             LedgerApiDialogues, self.context.ledger_api_dialogues
         )
-        ledger_api_msg = LedgerApiMessage(
+        ledger_api_msg, ledger_api_dialogue = ledger_api_dialogues.create(
+            counterparty=LEDGER_API_ADDRESS,
             performative=LedgerApiMessage.Performative.SEND_SIGNED_TRANSACTION,
-            dialogue_reference=ledger_api_dialogues.new_self_initiated_dialogue_reference(),
             signed_transaction=signing_msg.signed_transaction,
         )
-        ledger_api_msg.counterparty = LEDGER_API_ADDRESS
-        ledger_api_dialogue = cast(
-            Optional[LedgerApiDialogue], ledger_api_dialogues.update(ledger_api_msg)
-        )
-        assert ledger_api_dialogue is not None, "Error when creating signing dialogue."
+        ledger_api_dialogue = cast(LedgerApiDialogue, ledger_api_dialogue)
         ledger_api_dialogue.associated_signing_dialogue = signing_dialogue
         self.context.outbox.put_message(message=ledger_api_msg)
         self.context.logger.info("sending transaction to ledger.")
