@@ -42,7 +42,7 @@ from packages.fetchai.skills.generic_seller.dialogues import (
 )
 from packages.fetchai.skills.generic_seller.strategy import GenericStrategy
 
-LEDGER_API_ADDRESS = "fetchai/ledger:0.3.0"
+LEDGER_API_ADDRESS = "fetchai/ledger:0.4.0"
 
 
 class GenericFipaHandler(Handler):
@@ -100,15 +100,13 @@ class GenericFipaHandler(Handler):
             "received invalid fipa message={}, unidentified dialogue.".format(fipa_msg)
         )
         default_dialogues = cast(DefaultDialogues, self.context.default_dialogues)
-        default_msg = DefaultMessage(
+        default_msg, _ = default_dialogues.create(
+            counterparty=fipa_msg.sender,
             performative=DefaultMessage.Performative.ERROR,
-            dialogue_reference=default_dialogues.new_self_initiated_dialogue_reference(),
             error_code=DefaultMessage.ErrorCode.INVALID_DIALOGUE,
             error_msg="Invalid dialogue.",
             error_data={"fipa_message": fipa_msg.encode()},
         )
-        default_msg.counterparty = fipa_msg.counterparty
-        default_dialogues.update(default_msg)
         self.context.outbox.put_message(message=default_msg)
 
     def _handle_cfp(self, fipa_msg: FipaMessage, fipa_dialogue: FipaDialogue) -> None:
@@ -122,42 +120,33 @@ class GenericFipaHandler(Handler):
         :return: None
         """
         self.context.logger.info(
-            "received CFP from sender={}".format(fipa_msg.counterparty[-5:])
+            "received CFP from sender={}".format(fipa_msg.sender[-5:])
         )
         strategy = cast(GenericStrategy, self.context.strategy)
         if strategy.is_matching_supply(fipa_msg.query):
             proposal, terms, data_for_sale = strategy.generate_proposal_terms_and_data(
-                fipa_msg.query, fipa_msg.counterparty
+                fipa_msg.query, fipa_msg.sender
             )
             fipa_dialogue.data_for_sale = data_for_sale
             fipa_dialogue.terms = terms
             self.context.logger.info(
                 "sending a PROPOSE with proposal={} to sender={}".format(
-                    proposal.values, fipa_msg.counterparty[-5:]
+                    proposal.values, fipa_msg.sender[-5:]
                 )
             )
-            proposal_msg = FipaMessage(
+            proposal_msg = fipa_dialogue.reply(
                 performative=FipaMessage.Performative.PROPOSE,
-                message_id=fipa_msg.message_id + 1,
-                dialogue_reference=fipa_dialogue.dialogue_label.dialogue_reference,
-                target=fipa_msg.message_id,
+                target_message=fipa_msg,
                 proposal=proposal,
             )
-            proposal_msg.counterparty = fipa_msg.counterparty
-            fipa_dialogue.update(proposal_msg)
             self.context.outbox.put_message(message=proposal_msg)
         else:
             self.context.logger.info(
-                "declined the CFP from sender={}".format(fipa_msg.counterparty[-5:])
+                "declined the CFP from sender={}".format(fipa_msg.sender[-5:])
             )
-            decline_msg = FipaMessage(
-                message_id=fipa_msg.message_id + 1,
-                dialogue_reference=fipa_dialogue.dialogue_label.dialogue_reference,
-                target=fipa_msg.message_id,
-                performative=FipaMessage.Performative.DECLINE,
+            decline_msg = fipa_dialogue.reply(
+                performative=FipaMessage.Performative.DECLINE, target_message=fipa_msg,
             )
-            decline_msg.counterparty = fipa_msg.counterparty
-            fipa_dialogue.update(decline_msg)
             self.context.outbox.put_message(message=decline_msg)
 
     def _handle_decline(
@@ -176,7 +165,7 @@ class GenericFipaHandler(Handler):
         :return: None
         """
         self.context.logger.info(
-            "received DECLINE from sender={}".format(fipa_msg.counterparty[-5:])
+            "received DECLINE from sender={}".format(fipa_msg.sender[-5:])
         )
         fipa_dialogues.dialogue_stats.add_dialogue_endstate(
             FipaDialogue.EndState.DECLINED_PROPOSE, fipa_dialogue.is_self_initiated
@@ -195,22 +184,19 @@ class GenericFipaHandler(Handler):
         :return: None
         """
         self.context.logger.info(
-            "received ACCEPT from sender={}".format(fipa_msg.counterparty[-5:])
+            "received ACCEPT from sender={}".format(fipa_msg.sender[-5:])
         )
-        match_accept_msg = FipaMessage(
+        info = {"address": fipa_dialogue.terms.sender_address}
+        match_accept_msg = fipa_dialogue.reply(
             performative=FipaMessage.Performative.MATCH_ACCEPT_W_INFORM,
-            message_id=fipa_msg.message_id + 1,
-            dialogue_reference=fipa_dialogue.dialogue_label.dialogue_reference,
-            target=fipa_msg.message_id,
-            info={"address": fipa_dialogue.terms.sender_address},
+            target_message=fipa_msg,
+            info=info,
         )
         self.context.logger.info(
             "sending MATCH_ACCEPT_W_INFORM to sender={} with info={}".format(
-                fipa_msg.counterparty[-5:], match_accept_msg.info,
+                fipa_msg.sender[-5:], info,
             )
         )
-        match_accept_msg.counterparty = fipa_msg.counterparty
-        fipa_dialogue.update(match_accept_msg)
         self.context.outbox.put_message(message=match_accept_msg)
 
     def _handle_inform(
@@ -226,10 +212,8 @@ class GenericFipaHandler(Handler):
         :param fipa_dialogue: the dialogue object
         :return: None
         """
-        new_message_id = fipa_msg.message_id + 1
-        new_target = fipa_msg.message_id
         self.context.logger.info(
-            "received INFORM from sender={}".format(fipa_msg.counterparty[-5:])
+            "received INFORM from sender={}".format(fipa_msg.sender[-5:])
         )
 
         strategy = cast(GenericStrategy, self.context.strategy)
@@ -242,38 +226,28 @@ class GenericFipaHandler(Handler):
             ledger_api_dialogues = cast(
                 LedgerApiDialogues, self.context.ledger_api_dialogues
             )
-            ledger_api_msg = LedgerApiMessage(
+            ledger_api_msg, ledger_api_dialogue = ledger_api_dialogues.create(
+                counterparty=LEDGER_API_ADDRESS,
                 performative=LedgerApiMessage.Performative.GET_TRANSACTION_RECEIPT,
-                dialogue_reference=ledger_api_dialogues.new_self_initiated_dialogue_reference(),
                 transaction_digest=TransactionDigest(
                     fipa_dialogue.terms.ledger_id, fipa_msg.info["transaction_digest"]
                 ),
             )
-            ledger_api_msg.counterparty = LEDGER_API_ADDRESS
-            ledger_api_dialogue = cast(
-                Optional[LedgerApiDialogue], ledger_api_dialogues.update(ledger_api_msg)
-            )
-            assert (
-                ledger_api_dialogue is not None
-            ), "LedgerApiDialogue construction failed."
+            ledger_api_dialogue = cast(LedgerApiDialogue, ledger_api_dialogue)
             ledger_api_dialogue.associated_fipa_dialogue = fipa_dialogue
             self.context.outbox.put_message(message=ledger_api_msg)
         elif strategy.is_ledger_tx:
             self.context.logger.warning(
                 "did not receive transaction digest from sender={}.".format(
-                    fipa_msg.counterparty[-5:]
+                    fipa_msg.sender[-5:]
                 )
             )
         elif not strategy.is_ledger_tx and "Done" in fipa_msg.info.keys():
-            inform_msg = FipaMessage(
-                message_id=new_message_id,
-                dialogue_reference=fipa_dialogue.dialogue_label.dialogue_reference,
-                target=new_target,
+            inform_msg = fipa_dialogue.reply(
                 performative=FipaMessage.Performative.INFORM,
+                target_message=fipa_msg,
                 info=fipa_dialogue.data_for_sale,
             )
-            inform_msg.counterparty = fipa_msg.counterparty
-            fipa_dialogue.update(inform_msg)
             self.context.outbox.put_message(message=inform_msg)
             fipa_dialogues = cast(FipaDialogues, self.context.fipa_dialogues)
             fipa_dialogues.dialogue_stats.add_dialogue_endstate(
@@ -281,13 +255,13 @@ class GenericFipaHandler(Handler):
             )
             self.context.logger.info(
                 "transaction confirmed, sending data={} to buyer={}.".format(
-                    fipa_dialogue.data_for_sale, fipa_msg.counterparty[-5:],
+                    fipa_dialogue.data_for_sale, fipa_msg.sender[-5:],
                 )
             )
         else:
             self.context.logger.warning(
                 "did not receive transaction confirmation from sender={}.".format(
-                    fipa_msg.counterparty[-5:]
+                    fipa_msg.sender[-5:]
                 )
             )
 
@@ -339,7 +313,7 @@ class GenericLedgerApiHandler(Handler):
 
         # handle message
         if ledger_api_msg.performative is LedgerApiMessage.Performative.BALANCE:
-            self._handle_balance(ledger_api_msg, ledger_api_dialogue)
+            self._handle_balance(ledger_api_msg)
         elif (
             ledger_api_msg.performative
             is LedgerApiMessage.Performative.TRANSACTION_RECEIPT
@@ -370,14 +344,11 @@ class GenericLedgerApiHandler(Handler):
             )
         )
 
-    def _handle_balance(
-        self, ledger_api_msg: LedgerApiMessage, ledger_api_dialogue: LedgerApiDialogue
-    ) -> None:
+    def _handle_balance(self, ledger_api_msg: LedgerApiMessage) -> None:
         """
         Handle a message of balance performative.
 
         :param ledger_api_message: the ledger api message
-        :param ledger_api_dialogue: the ledger api dialogue
         """
         self.context.logger.info(
             "starting balance on {} ledger={}.".format(
@@ -410,16 +381,13 @@ class GenericLedgerApiHandler(Handler):
             last_message = cast(
                 Optional[FipaMessage], fipa_dialogue.last_incoming_message
             )
-            assert last_message is not None, "Cannot retrieve last fipa message."
-            inform_msg = FipaMessage(
-                message_id=last_message.message_id + 1,
-                dialogue_reference=fipa_dialogue.dialogue_label.dialogue_reference,
-                target=last_message.message_id,
+            if last_message is None:
+                raise ValueError("Cannot retrieve last fipa message.")
+            inform_msg = fipa_dialogue.reply(
                 performative=FipaMessage.Performative.INFORM,
+                target_message=last_message,
                 info=fipa_dialogue.data_for_sale,
             )
-            inform_msg.counterparty = last_message.counterparty
-            fipa_dialogue.update(inform_msg)
             self.context.outbox.put_message(message=inform_msg)
             fipa_dialogues = cast(FipaDialogues, self.context.fipa_dialogues)
             fipa_dialogues.dialogue_stats.add_dialogue_endstate(
@@ -427,7 +395,7 @@ class GenericLedgerApiHandler(Handler):
             )
             self.context.logger.info(
                 "transaction confirmed, sending data={} to buyer={}.".format(
-                    fipa_dialogue.data_for_sale, last_message.counterparty[-5:],
+                    fipa_dialogue.data_for_sale, last_message.sender[-5:],
                 )
             )
         else:
