@@ -21,7 +21,7 @@
 
 from typing import Dict, Optional, Tuple, cast
 
-from aea.mail.base import Address
+from aea.common import Address
 from aea.protocols.base import Message
 from aea.protocols.state_update.message import StateUpdateMessage
 from aea.skills.base import Handler
@@ -112,7 +112,8 @@ class OefSearchHandler(Handler):
         """
         self.context.logger.warning(
             "received OEF Search error: dialogue_reference={}, oef_error_operation={}".format(
-                oef_search_msg.dialogue_reference, oef_search_msg.oef_error_operation,
+                oef_search_dialogue.dialogue_label.dialogue_reference,
+                oef_search_msg.oef_error_operation,
             )
         )
 
@@ -128,7 +129,8 @@ class OefSearchHandler(Handler):
         """
         self.context.logger.debug(
             "on search result: dialogue_reference={} agents={}".format(
-                oef_search_msg.dialogue_reference, oef_search_msg.agents,
+                oef_search_dialogue.dialogue_label.dialogue_reference,
+                oef_search_msg.agents,
             )
         )
         self._on_controller_search_result(oef_search_msg.agents)
@@ -189,14 +191,12 @@ class OefSearchHandler(Handler):
         game.update_expected_controller_addr(controller_addr)
         game.update_game_phase(Phase.GAME_REGISTRATION)
         tac_dialogues = cast(TacDialogues, self.context.tac_dialogues)
-        tac_msg = TacMessage(
+        tac_msg, tac_dialogue = tac_dialogues.create(
+            counterparty=controller_addr,
             performative=TacMessage.Performative.REGISTER,
-            dialogue_reference=tac_dialogues.new_self_initiated_dialogue_reference(),
             agent_name=self.context.agent_name,
         )
-        tac_msg.counterparty = controller_addr
-        tac_dialogue = cast(Optional[TacDialogue], tac_dialogues.update(tac_msg))
-        assert tac_dialogue is not None, "TacDialogue not created."
+        tac_dialogue = cast(TacDialogue, tac_dialogue)
         game.tac_dialogue = tac_dialogue
         self.context.outbox.put_message(message=tac_msg)
         self.context.behaviours.tac_search.is_active = False
@@ -236,7 +236,7 @@ class TacHandler(Handler):
         self.context.logger.debug(
             "handling controller response. performative={}".format(tac_msg.performative)
         )
-        if tac_msg.counterparty != game.expected_controller_addr:
+        if tac_msg.sender != game.expected_controller_addr:
             raise ValueError(
                 "The sender of the message is not the controller agent we registered with."
             )
@@ -244,11 +244,11 @@ class TacHandler(Handler):
         if tac_msg.performative == TacMessage.Performative.TAC_ERROR:
             self._on_tac_error(tac_msg, tac_dialogue)
         elif tac_msg.performative == TacMessage.Performative.GAME_DATA:
-            self._on_start(tac_msg, tac_dialogue)
+            self._on_start(tac_msg)
         elif tac_msg.performative == TacMessage.Performative.CANCELLED:
-            self._on_cancelled(tac_msg, tac_dialogue)
+            self._on_cancelled(tac_msg)
         elif tac_msg.performative == TacMessage.Performative.TRANSACTION_CONFIRMATION:
-            self._on_transaction_confirmed(tac_msg, tac_dialogue)
+            self._on_transaction_confirmed(tac_msg)
         else:
             self._handle_invalid(tac_msg, tac_dialogue)
 
@@ -280,8 +280,8 @@ class TacHandler(Handler):
         """
         error_code = tac_msg.error_code
         self.context.logger.debug(
-            "received error from the controller. error_msg={}".format(
-                TacMessage.ErrorCode.to_msg(error_code.value)
+            "received error from the controller in dialogue={}. error_msg={}".format(
+                tac_dialogue, TacMessage.ErrorCode.to_msg(error_code.value)
             )
         )
         if error_code == TacMessage.ErrorCode.TRANSACTION_NOT_VALID:
@@ -295,12 +295,11 @@ class TacHandler(Handler):
                 "received error on transaction id: {}".format(transaction_id[-10:])
             )
 
-    def _on_start(self, tac_msg: TacMessage, tac_dialogue: TacDialogue) -> None:
+    def _on_start(self, tac_msg: TacMessage) -> None:
         """
         Handle the 'start' event emitted by the controller.
 
         :param tac_msg: the game data
-        :param tac_dialogue: the tac dialogue
         :return: None
         """
         game = cast(Game, self.context.game)
@@ -316,7 +315,7 @@ class TacHandler(Handler):
             "received start event from the controller. Starting to compete..."
         )
         game = cast(Game, self.context.game)
-        game.init(tac_msg, tac_msg.counterparty)
+        game.init(tac_msg, tac_msg.sender)
         game.update_game_phase(Phase.GAME)
 
         if game.is_using_contract:
@@ -330,58 +329,48 @@ class TacHandler(Handler):
                 self.context.logger.info(
                     "received a contract address: {}".format(contract_address)
                 )
-                # TODO; verify on-chain matches off-chain wealth
-                self._update_ownership_and_preferences(tac_msg, tac_dialogue)
+                self._update_ownership_and_preferences(tac_msg)
             else:
                 self.context.logger.warning("did not receive a contract address!")
         else:
-            self._update_ownership_and_preferences(tac_msg, tac_dialogue)
+            self._update_ownership_and_preferences(tac_msg)
 
-    def _update_ownership_and_preferences(
-        self, tac_msg: TacMessage, tac_dialogue: TacDialogue
-    ) -> None:
+    def _update_ownership_and_preferences(self, tac_msg: TacMessage) -> None:
         """
         Update ownership and preferences.
 
         :param tac_msg: the game data
-        :param tac_dialogue: the tac dialogue
         :return: None
         """
         state_update_dialogues = cast(
             StateUpdateDialogues, self.context.state_update_dialogues
         )
-        state_update_msg = StateUpdateMessage(
+        state_update_msg, state_update_dialogue = state_update_dialogues.create(
+            counterparty="decision_maker",
             performative=StateUpdateMessage.Performative.INITIALIZE,
-            dialogue_reference=state_update_dialogues.new_self_initiated_dialogue_reference(),
             amount_by_currency_id=tac_msg.amount_by_currency_id,
             quantities_by_good_id=tac_msg.quantities_by_good_id,
             exchange_params_by_currency_id=tac_msg.exchange_params_by_currency_id,
             utility_params_by_good_id=tac_msg.utility_params_by_good_id,
         )
         self.context.shared_state["fee_by_currency_id"] = tac_msg.fee_by_currency_id
-        state_update_msg.counterparty = "decision_maker"
-        state_update_dialogue = cast(
-            Optional[StateUpdateDialogue],
-            state_update_dialogues.update(state_update_msg),
-        )
-        assert state_update_dialogue is not None, "StateUpdateDialogue not created."
+        state_update_dialogue = cast(StateUpdateDialogue, state_update_dialogue)
         game = cast(Game, self.context.game)
         game.state_update_dialogue = state_update_dialogue
         self.context.decision_maker_message_queue.put_nowait(state_update_msg)
 
-    def _on_cancelled(self, tac_msg: TacMessage, tac_dialogue: TacDialogue) -> None:
+    def _on_cancelled(self, tac_msg: TacMessage) -> None:
         """
         Handle the cancellation of the competition from the TAC controller.
 
         :param tac_msg: the TacMessage.
-        :param tac_dialogue: the tac dialogue
         :return: None
         """
         game = cast(Game, self.context.game)
         if game.phase.value not in [Phase.GAME_REGISTRATION.value, Phase.GAME.value]:
             self.context.logger.warning(
-                "we do not expect a start message in game phase={}".format(
-                    game.phase.value
+                "we do not expect a message in game phase={}, received msg={}".format(
+                    game.phase.value, tac_msg
                 )
             )
             return
@@ -392,21 +381,18 @@ class TacHandler(Handler):
         self.context.is_active = False
         self.context.shared_state["is_game_finished"] = True
 
-    def _on_transaction_confirmed(
-        self, tac_msg: TacMessage, tac_dialogue: TacDialogue
-    ) -> None:
+    def _on_transaction_confirmed(self, tac_msg: TacMessage) -> None:
         """
         Handle 'on transaction confirmed' event emitted by the controller.
 
         :param tac_msg: the TacMessage.
-        :param tac_dialogue: the tac dialogue
         :return: None
         """
         game = cast(Game, self.context.game)
         if game.phase.value != Phase.GAME.value:
             self.context.logger.warning(
-                "we do not expect a tranasaction in game phase={}".format(
-                    game.phase.value
+                "we do not expect a tranasaction in game phase={}, received msg={}".format(
+                    game.phase.value, tac_msg
                 )
             )
             return
@@ -418,17 +404,14 @@ class TacHandler(Handler):
         )
         state_update_dialogue = game.state_update_dialogue
         last_msg = state_update_dialogue.last_message
-        assert last_msg is not None, "Could not retrieve last message."
-        state_update_msg = StateUpdateMessage(
+        if last_msg is None:
+            raise ValueError("Could not retrieve last message.")
+        state_update_msg = state_update_dialogue.reply(
             performative=StateUpdateMessage.Performative.APPLY,
-            dialogue_reference=state_update_dialogue.dialogue_label.dialogue_reference,
-            message_id=last_msg.message_id + 1,
-            target=last_msg.message_id,
+            target_message=last_msg,
             amount_by_currency_id=tac_msg.amount_by_currency_id,
             quantities_by_good_id=tac_msg.quantities_by_good_id,
         )
-        state_update_msg.counterparty = "decision_maker"
-        state_update_dialogue.update(state_update_msg)
         self.context.decision_maker_message_queue.put_nowait(state_update_msg)
         if "confirmed_tx_ids" not in self.context.shared_state.keys():
             self.context.shared_state["confirmed_tx_ids"] = []
