@@ -25,8 +25,6 @@ import shutil
 import tempfile
 from pathlib import Path
 
-from click.testing import CliRunner
-
 import jsonschema
 from jsonschema import Draft4Validator
 
@@ -40,6 +38,7 @@ from tests.conftest import (
     CLI_LOG_OPTION,
     CONFIGURATION_SCHEMA_DIR,
     CUR_PATH,
+    CliRunner,
     MAX_FLAKY_RERUNS,
 )
 
