@@ -21,7 +21,6 @@
 from unittest import TestCase, mock
 
 from click import ClickException
-from click.testing import CliRunner
 
 from aea.cli import cli
 from aea.cli.publish import (
@@ -30,7 +29,7 @@ from aea.cli.publish import (
     _validate_pkp,
 )
 
-from tests.conftest import CLI_LOG_OPTION
+from tests.conftest import CLI_LOG_OPTION, CliRunner
 from tests.test_cli.tools_for_testing import (
     ContextMock,
     PublicIdMock,
