@@ -27,8 +27,6 @@ import tempfile
 import unittest.mock
 from pathlib import Path
 
-from click.testing import CliRunner
-
 import jsonschema
 from jsonschema import Draft4Validator, ValidationError
 
@@ -44,6 +42,7 @@ from tests.conftest import (
     CLI_LOG_OPTION,
     CONFIGURATION_SCHEMA_DIR,
     CONNECTION_CONFIGURATION_SCHEMA,
+    CliRunner,
 )
 
 
