@@ -27,8 +27,8 @@ from typing import cast
 from aea import AEA_DIR
 from aea.aea import AEA
 from aea.configurations.base import ConnectionConfig, PublicId
-from aea.crypto.cosmos import CosmosCrypto
-from aea.crypto.helpers import COSMOS_PRIVATE_KEY_FILE, create_private_key
+from aea.crypto.fetchai import FetchAICrypto
+from aea.crypto.helpers import PRIVATE_KEY_PATH_SCHEMA, create_private_key
 from aea.crypto.wallet import Wallet
 from aea.identity.base import Identity
 from aea.protocols.base import Protocol
@@ -44,9 +44,12 @@ API_KEY = "TwiCIriSl0mLahw17pyqoA"
 SOEF_ADDR = "soef.fetch.ai"
 SOEF_PORT = 9002
 ENTRY_PEER_ADDRESS = (
-    "/dns4/127.0.0.1/tcp/9000/p2p/16Uiu2HAmAzvu5uNbcnD2qaqrkSULhJsc6GJUg3iikWerJkoD72pr"
+    "/dns4/127.0.0.1/tcp/9000/p2p/16Uiu2HAmLBCAqHL8SuFosyDhAKYsLKXBZBWXBsB9oFw2qU4Kckun"
+)
+FETCHAI_PRIVATE_KEY_FILE = PRIVATE_KEY_PATH_SCHEMA.format(FetchAICrypto.identifier)
+FETCHAI_PRIVATE_KEY_FILE_CONNECTION = PRIVATE_KEY_PATH_SCHEMA.format(
+    "fetchai_connection"
 )
-COSMOS_PRIVATE_KEY_FILE_CONNECTION = "cosmos_connection_private_key.txt"
 ROOT_DIR = os.getcwd()
 
 logger = logging.getLogger("aea")
@@ -55,23 +58,25 @@ logging.basicConfig(stream=sys.stdout, level=logging.INFO)
 
 def run():
     # Create a private key
-    create_private_key(CosmosCrypto.identifier, COSMOS_PRIVATE_KEY_FILE)
-    create_private_key(CosmosCrypto.identifier, COSMOS_PRIVATE_KEY_FILE_CONNECTION)
+    create_private_key(FetchAICrypto.identifier, FETCHAI_PRIVATE_KEY_FILE)
+    create_private_key(FetchAICrypto.identifier, FETCHAI_PRIVATE_KEY_FILE_CONNECTION)
 
     # Set up the wallet, identity and (empty) resources
     wallet = Wallet(
-        private_key_paths={CosmosCrypto.identifier: COSMOS_PRIVATE_KEY_FILE},
+        private_key_paths={FetchAICrypto.identifier: FETCHAI_PRIVATE_KEY_FILE},
         connection_private_key_paths={
-            CosmosCrypto.identifier: COSMOS_PRIVATE_KEY_FILE_CONNECTION
+            FetchAICrypto.identifier: FETCHAI_PRIVATE_KEY_FILE_CONNECTION
         },
     )
-    identity = Identity("my_aea", address=wallet.addresses.get(CosmosCrypto.identifier))
+    identity = Identity(
+        "my_aea", address=wallet.addresses.get(FetchAICrypto.identifier)
+    )
     resources = Resources()
 
     # specify the default routing for some protocols
     default_routing = {
-        PublicId.from_str("fetchai/ledger_api:0.2.0"): LedgerConnection.connection_id,
-        PublicId.from_str("fetchai/oef_search:0.4.0"): SOEFConnection.connection_id,
+        PublicId.from_str("fetchai/ledger_api:0.3.0"): LedgerConnection.connection_id,
+        PublicId.from_str("fetchai/oef_search:0.5.0"): SOEFConnection.connection_id,
     }
     default_connection = P2PLibp2pConnection.connection_id
 
@@ -138,7 +143,7 @@ def run():
         api_key=API_KEY,
         soef_addr=SOEF_ADDR,
         soef_port=SOEF_PORT,
-        restricted_to_protocols={PublicId.from_str("fetchai/oef_search:0.4.0")},
+        restricted_to_protocols={PublicId.from_str("fetchai/oef_search:0.5.0")},
         connection_id=SOEFConnection.connection_id,
     )
     soef_connection = SOEFConnection(configuration=configuration, identity=identity)
