@@ -29,12 +29,12 @@ import pytest
 from aea.test_tools.test_cases import AEATestCaseMany
 
 from tests.conftest import (
-    COSMOS,
-    COSMOS_PRIVATE_KEY_FILE,
-    COSMOS_PRIVATE_KEY_FILE_CONNECTION,
     CUR_PATH,
+    FETCHAI,
+    FETCHAI_PRIVATE_KEY_FILE,
+    FETCHAI_PRIVATE_KEY_FILE_CONNECTION,
     MAX_FLAKY_RERUNS_INTEGRATION,
-    NON_FUNDED_COSMOS_PRIVATE_KEY_1,
+    NON_FUNDED_FETCHAI_PRIVATE_KEY_1,
     ROOT_DIR,
     wait_for_localhost_ports_to_close,
 )
@@ -62,7 +62,7 @@ class TestCliVsProgrammaticAEA(AEATestCaseMany):
         """Test the communication of the two agents."""
 
         weather_station = "weather_station"
-        self.fetch_agent("fetchai/weather_station:0.10.0", weather_station)
+        self.fetch_agent("fetchai/weather_station:0.11.0", weather_station)
         self.set_agent_context(weather_station)
         self.set_config(
             "vendor.fetchai.skills.weather_station.models.strategy.args.is_ledger_tx",
@@ -72,14 +72,14 @@ class TestCliVsProgrammaticAEA(AEATestCaseMany):
         self.run_install()
 
         # add non-funded key
-        self.generate_private_key(COSMOS)
-        self.generate_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION)
-        self.add_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE)
+        self.generate_private_key(FETCHAI)
+        self.generate_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE_CONNECTION)
+        self.add_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE)
         self.add_private_key(
-            COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION, connection=True
+            FETCHAI, FETCHAI_PRIVATE_KEY_FILE_CONNECTION, connection=True
         )
         self.replace_private_key_in_file(
-            NON_FUNDED_COSMOS_PRIVATE_KEY_1, COSMOS_PRIVATE_KEY_FILE_CONNECTION
+            NON_FUNDED_FETCHAI_PRIVATE_KEY_1, FETCHAI_PRIVATE_KEY_FILE_CONNECTION
         )
         # generate random location
         location = {
@@ -172,12 +172,13 @@ class TestCliVsProgrammaticAEA(AEATestCaseMany):
         """Inject location into the weather client strategy."""
         file = Path(dst_file_path)
         lines = file.read_text().splitlines()
+        line_insertion_position = 163  # line below: `strategy._is_ledger_tx = False`
         lines.insert(
-            157,
+            line_insertion_position,
             "    from packages.fetchai.skills.generic_buyer.strategy import Location",
         )
         lines.insert(
-            158,
+            line_insertion_position + 1,
             f"    strategy._agent_location = Location(longitude={location['longitude']}, latitude={location['latitude']})",
         )
         file.write_text("\n".join(lines))
