@@ -26,14 +26,14 @@ from typing import Optional, cast
 
 from aea.aea_builder import AEABuilder
 from aea.configurations.base import ProtocolId, SkillConfig
-from aea.crypto.cosmos import CosmosCrypto
+from aea.crypto.fetchai import FetchAICrypto
 from aea.crypto.helpers import create_private_key
 from aea.crypto.ledger_apis import LedgerApis
 from aea.crypto.wallet import Wallet
-from aea.helpers.dialogue.base import Dialogue, DialogueLabel
 from aea.helpers.transaction.base import RawTransaction, Terms
 from aea.identity.base import Identity
-from aea.protocols.base import Message
+from aea.protocols.base import Address, Message
+from aea.protocols.dialogue.base import Dialogue
 from aea.protocols.signing.dialogues import SigningDialogue
 from aea.protocols.signing.dialogues import SigningDialogues as BaseSigningDialogues
 from aea.protocols.signing.message import SigningMessage
@@ -42,14 +42,14 @@ from aea.skills.base import Handler, Model, Skill, SkillContext
 logger = logging.getLogger("aea")
 logging.basicConfig(level=logging.INFO)
 
-COSMOS_PRIVATE_KEY_FILE_1 = "cosmos_private_key_1.txt"
-COSMOS_PRIVATE_KEY_FILE_2 = "cosmos_private_key_2.txt"
+FETCHAI_PRIVATE_KEY_FILE_1 = "fetchai_private_key_1.txt"
+FETCHAI_PRIVATE_KEY_FILE_2 = "fetchai_private_key_2.txt"
 
 
 def run():
     # Create a private key
     create_private_key(
-        CosmosCrypto.identifier, private_key_file=COSMOS_PRIVATE_KEY_FILE_1
+        FetchAICrypto.identifier, private_key_file=FETCHAI_PRIVATE_KEY_FILE_1
     )
 
     # Instantiate the builder and build the AEA
@@ -58,7 +58,7 @@ def run():
 
     builder.set_name("my_aea")
 
-    builder.add_private_key(CosmosCrypto.identifier, COSMOS_PRIVATE_KEY_FILE_1)
+    builder.add_private_key(FetchAICrypto.identifier, FETCHAI_PRIVATE_KEY_FILE_1)
 
     # Create our AEA
     my_aea = builder.build()
@@ -70,7 +70,9 @@ def run():
         skill_context=skill_context, name="signing_handler"
     )
     signing_dialogues_model = SigningDialogues(
-        skill_context=skill_context, name="signing_dialogues"
+        skill_context=skill_context,
+        name="signing_dialogues",
+        self_address=str(skill_config.public_id),
     )
 
     simple_skill = Skill(
@@ -83,20 +85,20 @@ def run():
 
     # create a second identity
     create_private_key(
-        CosmosCrypto.identifier, private_key_file=COSMOS_PRIVATE_KEY_FILE_2
+        FetchAICrypto.identifier, private_key_file=FETCHAI_PRIVATE_KEY_FILE_2
     )
 
-    counterparty_wallet = Wallet({CosmosCrypto.identifier: COSMOS_PRIVATE_KEY_FILE_2})
+    counterparty_wallet = Wallet({FetchAICrypto.identifier: FETCHAI_PRIVATE_KEY_FILE_2})
 
     counterparty_identity = Identity(
         name="counterparty_aea",
         addresses=counterparty_wallet.addresses,
-        default_address_key=CosmosCrypto.identifier,
+        default_address_key=FetchAICrypto.identifier,
     )
 
     # create signing message for decision maker to sign
     terms = Terms(
-        ledger_id=CosmosCrypto.identifier,
+        ledger_id=FetchAICrypto.identifier,
         sender_address=my_aea.identity.address,
         counterparty_address=counterparty_identity.address,
         amount_by_currency_id={"FET": -1},
@@ -116,14 +118,12 @@ def run():
     signing_msg = SigningMessage(
         performative=SigningMessage.Performative.SIGN_TRANSACTION,
         dialogue_reference=signing_dialogues.new_self_initiated_dialogue_reference(),
-        skill_callback_ids=(str(skill_context.skill_id),),
-        raw_transaction=RawTransaction(CosmosCrypto.identifier, stub_transaction),
+        raw_transaction=RawTransaction(FetchAICrypto.identifier, stub_transaction),
         terms=terms,
-        skill_callback_info={"some_info_key": "some_info_value"},
     )
-    signing_msg.counterparty = "decision_maker"
     signing_dialogue = cast(
-        Optional[SigningDialogue], signing_dialogues.update(signing_msg)
+        Optional[SigningDialogue],
+        signing_dialogues.create_with_message("decision_maker", signing_msg),
     )
     assert signing_dialogue is not None
     my_aea.context.decision_maker_message_queue.put_nowait(signing_msg)
@@ -144,39 +144,32 @@ def run():
 
 
 class SigningDialogues(Model, BaseSigningDialogues):
-    def __init__(self, **kwargs) -> None:
+    """Signing dialogues model."""
+
+    def __init__(self, self_address: Address, **kwargs) -> None:
         """
         Initialize dialogues.
 
         :return: None
         """
         Model.__init__(self, **kwargs)
-        BaseSigningDialogues.__init__(self, self.context.agent_address)
 
-    @staticmethod
-    def role_from_first_message(message: Message) -> Dialogue.Role:
-        """Infer the role of the agent from an incoming/outgoing first message
+        def role_from_first_message(  # pylint: disable=unused-argument
+            message: Message, receiver_address: Address
+        ) -> Dialogue.Role:
+            """Infer the role of the agent from an incoming/outgoing first message
 
-        :param message: an incoming/outgoing first message
-        :return: The role of the agent
-        """
-        return SigningDialogue.Role.SKILL
+            :param message: an incoming/outgoing first message
+            :param receiver_address: the address of the receiving agent
+            :return: The role of the agent
+            """
+            return SigningDialogue.Role.SKILL
 
-    def create_dialogue(
-        self, dialogue_label: DialogueLabel, role: Dialogue.Role,
-    ) -> SigningDialogue:
-        """
-        Create an instance of fipa dialogue.
-
-        :param dialogue_label: the identifier of the dialogue
-        :param role: the role of the agent this dialogue is maintained for
-
-        :return: the created dialogue
-        """
-        dialogue = SigningDialogue(
-            dialogue_label=dialogue_label, agent_address=self.agent_address, role=role
+        BaseSigningDialogues.__init__(
+            self,
+            self_address=self_address,
+            role_from_first_message=role_from_first_message,
         )
-        return dialogue
 
 
 class SigningHandler(Handler):
