@@ -31,8 +31,9 @@ from aea.test_tools.test_cases import AEATestCaseMany
 
 from tests.conftest import (
     COSMOS,
-    COSMOS_PRIVATE_KEY_FILE,
     COSMOS_PRIVATE_KEY_FILE_CONNECTION,
+    FETCHAI,
+    FETCHAI_PRIVATE_KEY_FILE,
     MAX_FLAKY_RERUNS_INTEGRATION,
     NON_FUNDED_COSMOS_PRIVATE_KEY_1,
     NON_GENESIS_CONFIG,
@@ -60,7 +61,7 @@ seller_strategy_replacement = """models:
         temperature: 26
       has_data_source: false
       is_ledger_tx: true
-      ledger_id: cosmos
+      ledger_id: fetchai
       location:
         latitude: 0.127
         longitude: 51.5194
@@ -93,7 +94,7 @@ buyer_strategy_replacement = """models:
     args:
       currency_id: FET
       is_ledger_tx: true
-      ledger_id: cosmos
+      ledger_id: fetchai
       location:
         latitude: 0.127
         longitude: 51.5194
@@ -126,8 +127,8 @@ class TestOrmIntegrationDocs(AEATestCaseMany):
         self.create_agents(seller_aea_name, buyer_aea_name)
 
         default_routing = {
-            "fetchai/ledger_api:0.2.0": "fetchai/ledger:0.3.0",
-            "fetchai/oef_search:0.4.0": "fetchai/soef:0.6.0",
+            "fetchai/ledger_api:0.3.0": "fetchai/ledger:0.4.0",
+            "fetchai/oef_search:0.5.0": "fetchai/soef:0.7.0",
         }
 
         # generate random location
@@ -138,15 +139,15 @@ class TestOrmIntegrationDocs(AEATestCaseMany):
 
         # Setup seller
         self.set_agent_context(seller_aea_name)
-        self.add_item("connection", "fetchai/p2p_libp2p:0.7.0")
-        self.add_item("connection", "fetchai/soef:0.6.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.7.0")
-        self.add_item("connection", "fetchai/ledger:0.3.0")
-        self.add_item("skill", "fetchai/thermometer:0.9.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.8.0")
+        self.add_item("connection", "fetchai/soef:0.7.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.8.0")
+        self.add_item("connection", "fetchai/ledger:0.4.0")
+        self.add_item("skill", "fetchai/thermometer:0.10.0")
         setting_path = "agent.default_routing"
         self.force_set_config(setting_path, default_routing)
         # ejecting changes author and version!
-        self.eject_item("skill", "fetchai/thermometer:0.9.0")
+        self.eject_item("skill", "fetchai/thermometer:0.10.0")
         seller_skill_config_replacement = yaml.safe_load(seller_strategy_replacement)
         self.force_set_config(
             "skills.thermometer.models", seller_skill_config_replacement["models"],
@@ -166,15 +167,17 @@ class TestOrmIntegrationDocs(AEATestCaseMany):
         self.run_install()
 
         # add keys
-        self.generate_private_key(COSMOS)
+        self.generate_private_key(FETCHAI)
         self.generate_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION)
-        self.add_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE)
+        self.add_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE)
         self.add_private_key(
             COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION, connection=True
         )
         self.replace_private_key_in_file(
             NON_FUNDED_COSMOS_PRIVATE_KEY_1, COSMOS_PRIVATE_KEY_FILE_CONNECTION
         )
+        setting_path = "vendor.fetchai.connections.p2p_libp2p.config.ledger_id"
+        self.force_set_config(setting_path, COSMOS)
 
         # replace location
         setting_path = "skills.thermometer.models.strategy.args.location"
@@ -182,11 +185,11 @@ class TestOrmIntegrationDocs(AEATestCaseMany):
 
         # Setup Buyer
         self.set_agent_context(buyer_aea_name)
-        self.add_item("connection", "fetchai/p2p_libp2p:0.7.0")
-        self.add_item("connection", "fetchai/soef:0.6.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.7.0")
-        self.add_item("connection", "fetchai/ledger:0.3.0")
-        self.add_item("skill", "fetchai/thermometer_client:0.8.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.8.0")
+        self.add_item("connection", "fetchai/soef:0.7.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.8.0")
+        self.add_item("connection", "fetchai/ledger:0.4.0")
+        self.add_item("skill", "fetchai/thermometer_client:0.9.0")
         setting_path = "agent.default_routing"
         self.force_set_config(setting_path, default_routing)
         buyer_skill_config_replacement = yaml.safe_load(buyer_strategy_replacement)
@@ -197,19 +200,21 @@ class TestOrmIntegrationDocs(AEATestCaseMany):
         self.run_install()
 
         # add keys
-        self.generate_private_key(COSMOS)
+        self.generate_private_key(FETCHAI)
         self.generate_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION)
-        self.add_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE)
+        self.add_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE)
         self.add_private_key(
             COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION, connection=True
         )
 
         # fund key
-        self.generate_wealth(COSMOS)
+        self.generate_wealth(FETCHAI)
 
         # set p2p configs
         setting_path = "vendor.fetchai.connections.p2p_libp2p.config"
         self.force_set_config(setting_path, NON_GENESIS_CONFIG)
+        setting_path = "vendor.fetchai.connections.p2p_libp2p.config.ledger_id"
+        self.force_set_config(setting_path, COSMOS)
 
         # replace location
         setting_path = (
