@@ -19,11 +19,14 @@
 """This module contains the tests for AsyncFriendlyQueue."""
 import asyncio
 from concurrent.futures._base import CancelledError
+from contextlib import suppress
 
 import pytest
 
 from aea.helpers.async_utils import (
     AsyncState,
+    AwaitableProc,
+    HandlerItemGetter,
     PeriodicCaller,
     ThreadedAsyncRunner,
     cancel_and_wait,
@@ -65,6 +68,26 @@ async def test_async_state():
     await state.wait(2)
 
 
+@pytest.mark.asyncio
+async def test_async_state_transit():
+    """Test async state transit contextmanager."""
+    state = AsyncState()
+    state.set(None)
+
+    with state.transit(initial=1, success=2, fail=3):
+        assert state.get() == 1
+    assert state.get() == 2
+
+    state.set(None)
+
+    with suppress(ValueError):
+        with state.transit(initial=1, success=2, fail=3):
+            assert state.get() == 1
+            raise ValueError()
+
+    assert state.get() == 3
+
+
 @pytest.mark.asyncio
 async def test_asyncstate_with_list_of_valid_states():
     """Test various cases for AsyncState."""
@@ -210,3 +233,43 @@ async def test_cancel_and_wait():
     assert task.done()
     r = await cancel_and_wait(task)
     assert r is None
+
+
+@pytest.mark.asyncio
+async def test_handler_item_getter():
+    """Test item getter."""
+    q1, q2 = asyncio.Queue(), asyncio.Queue()
+    item1 = "item1"
+    item2 = "item2"
+    q1.put_nowait(item1)
+    q2.put_nowait(item2)
+    handler1_called = False
+    handler2_called = False
+
+    def handler1(item):
+        nonlocal handler1_called
+        handler1_called = item
+
+    def handler2(item):
+        nonlocal handler2_called
+        handler2_called = item
+
+    getter = HandlerItemGetter([(handler1, q1.get), (handler2, q2.get)])
+
+    handler, item = await getter.get()
+    handler(item)
+
+    handler, item = await getter.get()
+    handler(item)
+    assert handler1_called == item1
+    assert handler2_called == item2
+
+    with pytest.raises(asyncio.TimeoutError):
+        handler, item = await asyncio.wait_for(getter.get(), timeout=1)
+
+
+def test_libp2pconnection_awaitable_proc_cancelled():
+    """Test awaitable proc."""
+    proc = AwaitableProc(["sleep", "100"], shell=False)
+    proc_task = asyncio.ensure_future(proc.start())
+    proc_task.cancel()
