@@ -18,7 +18,6 @@
 # ------------------------------------------------------------------------------
 """Tests for the HTTP Client connection and channel."""
 import asyncio
-import copy
 import logging
 from asyncio import CancelledError
 from unittest.mock import Mock, patch
@@ -28,12 +27,15 @@ import aiohttp
 
 import pytest
 
+from aea.common import Address
 from aea.configurations.base import ConnectionConfig
 from aea.identity.base import Identity
-from aea.mail.base import Envelope
+from aea.mail.base import Envelope, Message
+from aea.protocols.dialogue.base import Dialogue as BaseDialogue
 
 from packages.fetchai.connections.http_client.connection import HTTPClientConnection
-from packages.fetchai.protocols.http.dialogues import HttpDialogues
+from packages.fetchai.protocols.http.dialogues import HttpDialogue
+from packages.fetchai.protocols.http.dialogues import HttpDialogues as BaseHttpDialogues
 from packages.fetchai.protocols.http.message import HttpMessage
 
 from tests.common.mocks import AnyStringWith
@@ -62,6 +64,34 @@ class _MockRequest:
         return None
 
 
+class HttpDialogues(BaseHttpDialogues):
+    """The dialogues class keeps track of all http dialogues."""
+
+    def __init__(self, self_address: Address, **kwargs) -> None:
+        """
+        Initialize dialogues.
+
+        :return: None
+        """
+
+        def role_from_first_message(  # pylint: disable=unused-argument
+            message: Message, receiver_address: Address
+        ) -> BaseDialogue.Role:
+            """Infer the role of the agent from an incoming/outgoing first message
+
+            :param message: an incoming/outgoing first message
+            :param receiver_address: the address of the receiving agent
+            :return: The role of the agent
+            """
+            return HttpDialogue.Role.CLIENT
+
+        BaseHttpDialogues.__init__(
+            self,
+            self_address=self_address,
+            role_from_first_message=role_from_first_message,
+        )
+
+
 @pytest.mark.asyncio
 class TestHTTPClientConnect:
     """Tests the http client connection's 'connect' functionality."""
@@ -80,9 +110,8 @@ class TestHTTPClientConnect:
         self.http_client_connection = HTTPClientConnection(
             configuration=configuration, identity=self.agent_identity
         )
-        self.http_client_connection.loop = asyncio.get_event_loop()
         self.connection_address = str(HTTPClientConnection.connection_id)
-        self.http_dialogs = HttpDialogues(self.connection_address)
+        self.http_dialogs = HttpDialogues(self.agent_address)
 
     @pytest.mark.asyncio
     async def test_initialization(self):
@@ -108,9 +137,8 @@ class TestHTTPClientConnect:
     async def test_http_send_error(self):
         """Test request fails and send back result with code 600."""
         await self.http_client_connection.connect()
-
-        request_http_message = HttpMessage(
-            dialogue_reference=self.http_dialogs.new_self_initiated_dialogue_reference(),
+        request_http_message, _ = self.http_dialogs.create(
+            counterparty=self.connection_address,
             performative=HttpMessage.Performative.REQUEST,
             method="get",
             url="bad url",
@@ -118,9 +146,6 @@ class TestHTTPClientConnect:
             version="",
             bodyy=b"",
         )
-        request_http_message.counterparty = self.connection_address
-        sending_dialogue = self.http_dialogs.update(request_http_message)
-        assert sending_dialogue is not None
         request_envelope = Envelope(
             to=self.connection_address,
             sender=self.agent_address,
@@ -156,8 +181,8 @@ class TestHTTPClientConnect:
     @pytest.mark.asyncio
     async def test_send_envelope_excluded_protocol_fail(self):
         """Test send error if protocol not supported."""
-        request_http_message = HttpMessage(
-            dialogue_reference=self.http_dialogs.new_self_initiated_dialogue_reference(),
+        request_http_message, _ = self.http_dialogs.create(
+            counterparty=self.connection_address,
             performative=HttpMessage.Performative.REQUEST,
             method="get",
             url="bad url",
@@ -165,9 +190,6 @@ class TestHTTPClientConnect:
             version="",
             bodyy=b"",
         )
-        request_http_message.counterparty = self.connection_address
-        sending_dialogue = self.http_dialogs.update(request_http_message)
-        assert sending_dialogue is not None
         request_envelope = Envelope(
             to=self.connection_address,
             sender=self.agent_address,
@@ -204,9 +226,8 @@ class TestHTTPClientConnect:
     async def test_channel_cancel_tasks_on_disconnect(self):
         """Test requests tasks cancelled on disconnect."""
         await self.http_client_connection.connect()
-
-        request_http_message = HttpMessage(
-            dialogue_reference=self.http_dialogs.new_self_initiated_dialogue_reference(),
+        request_http_message, _ = self.http_dialogs.create(
+            counterparty=self.connection_address,
             performative=HttpMessage.Performative.REQUEST,
             method="get",
             url="https://not-a-google.com",
@@ -214,9 +235,6 @@ class TestHTTPClientConnect:
             version="",
             bodyy=b"",
         )
-        request_http_message.counterparty = self.connection_address
-        sending_dialogue = self.http_dialogs.update(request_http_message)
-        assert sending_dialogue is not None
         request_envelope = Envelope(
             to=self.connection_address,
             sender=self.agent_address,
@@ -253,9 +271,8 @@ class TestHTTPClientConnect:
     async def test_http_send_ok(self):
         """Test request is ok cause mocked."""
         await self.http_client_connection.connect()
-
-        request_http_message = HttpMessage(
-            dialogue_reference=self.http_dialogs.new_self_initiated_dialogue_reference(),
+        request_http_message, sending_dialogue = self.http_dialogs.create(
+            counterparty=self.connection_address,
             performative=HttpMessage.Performative.REQUEST,
             method="get",
             url="https://not-a-google.com",
@@ -263,9 +280,6 @@ class TestHTTPClientConnect:
             version="",
             bodyy=b"",
         )
-        request_http_message.counterparty = self.connection_address
-        sending_dialogue = self.http_dialogs.update(request_http_message)
-        assert sending_dialogue is not None
         request_envelope = Envelope(
             to=self.connection_address,
             sender=self.agent_address,
@@ -294,11 +308,9 @@ class TestHTTPClientConnect:
             )
 
         assert envelope is not None and envelope.message is not None
-        response = copy.copy(envelope.message)
-        response.is_incoming = True
-        response.counterparty = envelope.message.sender
-        response_dialogue = self.http_dialogs.update(response)
-        assert response.status_code == response_mock.status, response.bodyy.decode(
+        message = envelope.message
+        response_dialogue = self.http_dialogs.update(message)
+        assert message.status_code == response_mock.status, message.bodyy.decode(
             "utf-8"
         )
         assert sending_dialogue == response_dialogue
@@ -309,7 +321,7 @@ class TestHTTPClientConnect:
         """Test dialogue not properly constructed."""
         await self.http_client_connection.connect()
 
-        http_message = HttpMessage(
+        incorrect_http_message = HttpMessage(
             dialogue_reference=self.http_dialogs.new_self_initiated_dialogue_reference(),
             performative=HttpMessage.Performative.RESPONSE,
             status_code=500,
@@ -318,15 +330,16 @@ class TestHTTPClientConnect:
             bodyy=b"",
             version="",
         )
-        http_message.counterparty = self.connection_address
-        http_dialogue = self.http_dialogs.update(http_message)
-        http_message.sender = self.agent_address
-        assert http_dialogue is None
+        incorrect_http_message.to = self.connection_address
+        incorrect_http_message.sender = self.agent_address
+
+        # the incorrect message cannot be sent into a dialogue, so this is omitted.
+
         envelope = Envelope(
-            to=http_message.counterparty,
-            sender=http_message.sender,
-            protocol_id=http_message.protocol_id,
-            message=http_message,
+            to=incorrect_http_message.to,
+            sender=incorrect_http_message.sender,
+            protocol_id=incorrect_http_message.protocol_id,
+            message=incorrect_http_message,
         )
         with patch.object(
             self.http_client_connection.channel.logger, "warning"
