@@ -19,7 +19,6 @@
 
 """This module contains the tests of the soef connection module."""
 
-import copy
 import logging
 import time
 from threading import Thread
@@ -66,7 +65,7 @@ def test_soef():
         api_key="TwiCIriSl0mLahw17pyqoA",
         soef_addr="soef.fetch.ai",
         soef_port=9002,
-        restricted_to_protocols={PublicId.from_str("fetchai/oef_search:0.4.0")},
+        restricted_to_protocols={PublicId.from_str("fetchai/oef_search:0.5.0")},
         connection_id=SOEFConnection.connection_id,
     )
     soef_connection = SOEFConnection(configuration=configuration, identity=identity,)
@@ -85,16 +84,13 @@ def test_soef():
         service_description = Description(
             service_instance, data_model=models.AGENT_LOCATION_MODEL
         )
-        message = OefSearchMessage(
+        message, _ = oef_search_dialogues.create(
+            counterparty=SOEFConnection.connection_id.latest,
             performative=OefSearchMessage.Performative.REGISTER_SERVICE,
-            dialogue_reference=oef_search_dialogues.new_self_initiated_dialogue_reference(),
             service_description=service_description,
         )
-        message.counterparty = SOEFConnection.connection_id.latest
-        sending_dialogue = oef_search_dialogues.update(message)
-        assert sending_dialogue is not None
         envelope = Envelope(
-            to=message.counterparty,
+            to=message.to,
             sender=message.sender,
             protocol_id=message.protocol_id,
             message=message,
@@ -111,16 +107,13 @@ def test_soef():
         service_description = Description(
             service_instance, data_model=models.AGENT_PERSONALITY_MODEL
         )
-        message = OefSearchMessage(
+        message, _ = oef_search_dialogues.create(
+            counterparty=SOEFConnection.connection_id.latest,
             performative=OefSearchMessage.Performative.REGISTER_SERVICE,
-            dialogue_reference=oef_search_dialogues.new_self_initiated_dialogue_reference(),
             service_description=service_description,
         )
-        message.counterparty = SOEFConnection.connection_id.latest
-        sending_dialogue = oef_search_dialogues.update(message)
-        assert sending_dialogue is not None
         envelope = Envelope(
-            to=message.counterparty,
+            to=message.to,
             sender=message.sender,
             protocol_id=message.protocol_id,
             message=message,
@@ -133,16 +126,13 @@ def test_soef():
         service_description = Description(
             service_instance, data_model=models.SET_SERVICE_KEY_MODEL
         )
-        message = OefSearchMessage(
+        message, _ = oef_search_dialogues.create(
+            counterparty=SOEFConnection.connection_id.latest,
             performative=OefSearchMessage.Performative.REGISTER_SERVICE,
-            dialogue_reference=oef_search_dialogues.new_self_initiated_dialogue_reference(),
             service_description=service_description,
         )
-        message.counterparty = SOEFConnection.connection_id.latest
-        sending_dialogue = oef_search_dialogues.update(message)
-        assert sending_dialogue is not None
         envelope = Envelope(
-            to=message.counterparty,
+            to=message.to,
             sender=message.sender,
             protocol_id=message.protocol_id,
             message=message,
@@ -158,16 +148,13 @@ def test_soef():
         closeness_query = Query(
             [close_to_my_service], model=models.AGENT_LOCATION_MODEL
         )
-        message = OefSearchMessage(
+        message, sending_dialogue = oef_search_dialogues.create(
+            counterparty=SOEFConnection.connection_id.latest,
             performative=OefSearchMessage.Performative.SEARCH_SERVICES,
-            dialogue_reference=oef_search_dialogues.new_self_initiated_dialogue_reference(),
             query=closeness_query,
         )
-        message.counterparty = SOEFConnection.connection_id.latest
-        sending_dialogue = oef_search_dialogues.update(message)
-        assert sending_dialogue is not None
         search_envelope = Envelope(
-            to=message.counterparty,
+            to=message.to,
             sender=message.sender,
             protocol_id=message.protocol_id,
             message=message,
@@ -182,26 +169,20 @@ def test_soef():
 
         # check for search results
         envelope = multiplexer.get()
-        orig_message = envelope.message
-        assert orig_message.performative == OefSearchMessage.Performative.SEARCH_RESULT
-        assert len(orig_message.agents) >= 0
-        message = copy.copy(orig_message)
-        message.is_incoming = True  # TODO: fix
-        message.counterparty = orig_message.sender  # TODO; fix
+        message = envelope.message
+        assert message.performative == OefSearchMessage.Performative.SEARCH_RESULT
+        assert len(message.agents) >= 0
         receiving_dialogue = oef_search_dialogues.update(message)
         assert sending_dialogue == receiving_dialogue
 
         # double send to check issue with too many requests
-        message = OefSearchMessage(
+        message, _ = oef_search_dialogues.create(
+            counterparty=SOEFConnection.connection_id.latest,
             performative=OefSearchMessage.Performative.SEARCH_SERVICES,
-            dialogue_reference=oef_search_dialogues.new_self_initiated_dialogue_reference(),
             query=closeness_query,
         )
-        message.counterparty = SOEFConnection.connection_id.latest
-        sending_dialogue = oef_search_dialogues.update(message)
-        assert sending_dialogue is not None
         search_envelope = Envelope(
-            to=message.counterparty,
+            to=message.to,
             sender=message.sender,
             protocol_id=message.protocol_id,
             message=message,
@@ -233,16 +214,13 @@ def test_soef():
 
         closeness_query = Query(constraints)
 
-        message = OefSearchMessage(
+        message, sending_dialogue = oef_search_dialogues.create(
+            counterparty=SOEFConnection.connection_id.latest,
             performative=OefSearchMessage.Performative.SEARCH_SERVICES,
-            dialogue_reference=oef_search_dialogues.new_self_initiated_dialogue_reference(),
             query=closeness_query,
         )
-        message.counterparty = SOEFConnection.connection_id.latest
-        sending_dialogue = oef_search_dialogues.update(message)
-        assert sending_dialogue is not None
         envelope = Envelope(
-            to=message.counterparty,
+            to=message.to,
             sender=message.sender,
             protocol_id=message.protocol_id,
             message=message,
@@ -257,27 +235,21 @@ def test_soef():
         wait_for_condition(lambda: not multiplexer.in_queue.empty(), timeout=20)
 
         envelope = multiplexer.get()
-        orig_message = envelope.message
-        assert orig_message.performative == OefSearchMessage.Performative.SEARCH_RESULT
-        assert len(orig_message.agents) >= 0
-        message = copy.copy(orig_message)
-        message.is_incoming = True  # TODO: fix
-        message.counterparty = orig_message.sender  # TODO; fix
+        message = envelope.message
+        assert message.performative == OefSearchMessage.Performative.SEARCH_RESULT
+        assert len(message.agents) >= 0
         receiving_dialogue = oef_search_dialogues.update(message)
         assert sending_dialogue == receiving_dialogue
 
         # test ping command
         service_description = Description({}, data_model=models.PING_MODEL)
-        message = OefSearchMessage(
+        message, _ = oef_search_dialogues.create(
+            counterparty=SOEFConnection.connection_id.latest,
             performative=OefSearchMessage.Performative.REGISTER_SERVICE,
-            dialogue_reference=oef_search_dialogues.new_self_initiated_dialogue_reference(),
             service_description=service_description,
         )
-        message.counterparty = SOEFConnection.connection_id.latest
-        sending_dialogue = oef_search_dialogues.update(message)
-        assert sending_dialogue is not None
         envelope = Envelope(
-            to=message.counterparty,
+            to=message.to,
             sender=crypto.address,
             protocol_id=message.protocol_id,
             message=message,
