@@ -27,8 +27,9 @@ from aea.test_tools.test_cases import AEATestCaseMany
 
 from tests.conftest import (
     COSMOS,
-    COSMOS_PRIVATE_KEY_FILE,
     COSMOS_PRIVATE_KEY_FILE_CONNECTION,
+    FETCHAI,
+    FETCHAI_PRIVATE_KEY_FILE,
     MAX_FLAKY_RERUNS_INTEGRATION,
     NON_FUNDED_COSMOS_PRIVATE_KEY_1,
     NON_GENESIS_CONFIG,
@@ -50,8 +51,8 @@ class TestCarPark(AEATestCaseMany):
         self.create_agents(carpark_aea_name, carpark_client_aea_name)
 
         default_routing = {
-            "fetchai/ledger_api:0.2.0": "fetchai/ledger:0.3.0",
-            "fetchai/oef_search:0.4.0": "fetchai/soef:0.6.0",
+            "fetchai/ledger_api:0.3.0": "fetchai/ledger:0.4.0",
+            "fetchai/oef_search:0.5.0": "fetchai/soef:0.7.0",
         }
 
         # generate random location
@@ -62,11 +63,11 @@ class TestCarPark(AEATestCaseMany):
 
         # Setup agent one
         self.set_agent_context(carpark_aea_name)
-        self.add_item("connection", "fetchai/p2p_libp2p:0.7.0")
-        self.add_item("connection", "fetchai/soef:0.6.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.7.0")
-        self.add_item("connection", "fetchai/ledger:0.3.0")
-        self.add_item("skill", "fetchai/carpark_detection:0.9.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.8.0")
+        self.add_item("connection", "fetchai/soef:0.7.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.8.0")
+        self.add_item("connection", "fetchai/ledger:0.4.0")
+        self.add_item("skill", "fetchai/carpark_detection:0.10.0")
         setting_path = (
             "vendor.fetchai.skills.carpark_detection.models.strategy.args.is_ledger_tx"
         )
@@ -76,9 +77,9 @@ class TestCarPark(AEATestCaseMany):
         self.run_install()
 
         # add keys
-        self.generate_private_key(COSMOS)
+        self.generate_private_key(FETCHAI)
         self.generate_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION)
-        self.add_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE)
+        self.add_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE)
         self.add_private_key(
             COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION, connection=True
         )
@@ -86,6 +87,9 @@ class TestCarPark(AEATestCaseMany):
             NON_FUNDED_COSMOS_PRIVATE_KEY_1, COSMOS_PRIVATE_KEY_FILE_CONNECTION
         )
 
+        setting_path = "vendor.fetchai.connections.p2p_libp2p.config.ledger_id"
+        self.force_set_config(setting_path, COSMOS)
+
         # replace location
         setting_path = (
             "vendor.fetchai.skills.carpark_detection.models.strategy.args.location"
@@ -94,11 +98,11 @@ class TestCarPark(AEATestCaseMany):
 
         # Setup agent two
         self.set_agent_context(carpark_client_aea_name)
-        self.add_item("connection", "fetchai/p2p_libp2p:0.7.0")
-        self.add_item("connection", "fetchai/soef:0.6.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.7.0")
-        self.add_item("connection", "fetchai/ledger:0.3.0")
-        self.add_item("skill", "fetchai/carpark_client:0.9.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.8.0")
+        self.add_item("connection", "fetchai/soef:0.7.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.8.0")
+        self.add_item("connection", "fetchai/ledger:0.4.0")
+        self.add_item("skill", "fetchai/carpark_client:0.10.0")
         setting_path = (
             "vendor.fetchai.skills.carpark_client.models.strategy.args.is_ledger_tx"
         )
@@ -108,9 +112,9 @@ class TestCarPark(AEATestCaseMany):
         self.run_install()
 
         # add keys
-        self.generate_private_key(COSMOS)
+        self.generate_private_key(FETCHAI)
         self.generate_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION)
-        self.add_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE)
+        self.add_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE)
         self.add_private_key(
             COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION, connection=True
         )
@@ -118,6 +122,8 @@ class TestCarPark(AEATestCaseMany):
         # set p2p configs
         setting_path = "vendor.fetchai.connections.p2p_libp2p.config"
         self.force_set_config(setting_path, NON_GENESIS_CONFIG)
+        setting_path = "vendor.fetchai.connections.p2p_libp2p.config.ledger_id"
+        self.force_set_config(setting_path, COSMOS)
 
         # replace location
         setting_path = (
@@ -220,8 +226,8 @@ class TestCarParkFetchaiLedger(AEATestCaseMany):
         self.create_agents(carpark_aea_name, carpark_client_aea_name)
 
         default_routing = {
-            "fetchai/ledger_api:0.2.0": "fetchai/ledger:0.3.0",
-            "fetchai/oef_search:0.4.0": "fetchai/soef:0.6.0",
+            "fetchai/ledger_api:0.3.0": "fetchai/ledger:0.4.0",
+            "fetchai/oef_search:0.5.0": "fetchai/soef:0.7.0",
         }
 
         # generate random location
@@ -232,26 +238,26 @@ class TestCarParkFetchaiLedger(AEATestCaseMany):
 
         # Setup agent one
         self.set_agent_context(carpark_aea_name)
-        self.add_item("connection", "fetchai/p2p_libp2p:0.7.0")
-        self.add_item("connection", "fetchai/soef:0.6.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.7.0")
-        self.add_item("connection", "fetchai/ledger:0.3.0")
-        self.add_item("skill", "fetchai/carpark_detection:0.9.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.8.0")
+        self.add_item("connection", "fetchai/soef:0.7.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.8.0")
+        self.add_item("connection", "fetchai/ledger:0.4.0")
+        self.add_item("skill", "fetchai/carpark_detection:0.10.0")
         setting_path = "agent.default_routing"
         self.force_set_config(setting_path, default_routing)
         self.run_install()
 
         diff = self.difference_to_fetched_agent(
-            "fetchai/car_detector:0.10.0", carpark_aea_name
+            "fetchai/car_detector:0.11.0", carpark_aea_name
         )
         assert (
             diff == []
         ), "Difference between created and fetched project for files={}".format(diff)
 
         # add keys
-        self.generate_private_key(COSMOS)
+        self.generate_private_key(FETCHAI)
         self.generate_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION)
-        self.add_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE)
+        self.add_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE)
         self.add_private_key(
             COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION, connection=True
         )
@@ -259,6 +265,9 @@ class TestCarParkFetchaiLedger(AEATestCaseMany):
             NON_FUNDED_COSMOS_PRIVATE_KEY_1, COSMOS_PRIVATE_KEY_FILE_CONNECTION
         )
 
+        setting_path = "vendor.fetchai.connections.p2p_libp2p.config.ledger_id"
+        self.force_set_config(setting_path, COSMOS)
+
         # replace location
         setting_path = (
             "vendor.fetchai.skills.carpark_detection.models.strategy.args.location"
@@ -267,39 +276,38 @@ class TestCarParkFetchaiLedger(AEATestCaseMany):
 
         # Setup agent two
         self.set_agent_context(carpark_client_aea_name)
-        self.add_item("connection", "fetchai/p2p_libp2p:0.7.0")
-        self.add_item("connection", "fetchai/soef:0.6.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.7.0")
-        self.add_item("connection", "fetchai/ledger:0.3.0")
-        self.add_item("skill", "fetchai/carpark_client:0.9.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.8.0")
+        self.add_item("connection", "fetchai/soef:0.7.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.8.0")
+        self.add_item("connection", "fetchai/ledger:0.4.0")
+        self.add_item("skill", "fetchai/carpark_client:0.10.0")
         setting_path = "agent.default_routing"
         self.force_set_config(setting_path, default_routing)
         self.run_install()
 
         diff = self.difference_to_fetched_agent(
-            "fetchai/car_data_buyer:0.10.0", carpark_client_aea_name
+            "fetchai/car_data_buyer:0.11.0", carpark_client_aea_name
         )
         assert (
             diff == []
         ), "Difference between created and fetched project for files={}".format(diff)
 
         # add keys
-        self.generate_private_key(COSMOS)
+        self.generate_private_key(FETCHAI)
         self.generate_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION)
-        self.add_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE)
+        self.add_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE)
         self.add_private_key(
             COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION, connection=True
         )
 
         # fund key
-        self.generate_wealth(COSMOS)
-        # self.replace_private_key_in_file(
-        #     FUNDED_COSMOS_PRIVATE_KEY_1, COSMOS_PRIVATE_KEY_FILE
-        # )
+        self.generate_wealth(FETCHAI)
 
         # set p2p configs
         setting_path = "vendor.fetchai.connections.p2p_libp2p.config"
         self.force_set_config(setting_path, NON_GENESIS_CONFIG)
+        setting_path = "vendor.fetchai.connections.p2p_libp2p.config.ledger_id"
+        self.force_set_config(setting_path, COSMOS)
 
         # replace location
         setting_path = (
