@@ -26,8 +26,9 @@ from aea.test_tools.test_cases import AEATestCaseMany
 
 from tests.conftest import (
     COSMOS,
-    COSMOS_PRIVATE_KEY_FILE,
     COSMOS_PRIVATE_KEY_FILE_CONNECTION,
+    FETCHAI,
+    FETCHAI_PRIVATE_KEY_FILE,
     MAX_FLAKY_RERUNS_INTEGRATION,
     NON_FUNDED_COSMOS_PRIVATE_KEY_1,
     NON_GENESIS_CONFIG,
@@ -49,8 +50,8 @@ class TestGenericSkills(AEATestCaseMany):
         self.create_agents(seller_aea_name, buyer_aea_name)
 
         default_routing = {
-            "fetchai/ledger_api:0.2.0": "fetchai/ledger:0.3.0",
-            "fetchai/oef_search:0.4.0": "fetchai/soef:0.6.0",
+            "fetchai/ledger_api:0.3.0": "fetchai/ledger:0.4.0",
+            "fetchai/oef_search:0.5.0": "fetchai/soef:0.7.0",
         }
 
         # generate random location
@@ -61,11 +62,11 @@ class TestGenericSkills(AEATestCaseMany):
 
         # prepare seller agent
         self.set_agent_context(seller_aea_name)
-        self.add_item("connection", "fetchai/p2p_libp2p:0.7.0")
-        self.add_item("connection", "fetchai/soef:0.6.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.7.0")
-        self.add_item("connection", "fetchai/ledger:0.3.0")
-        self.add_item("skill", "fetchai/generic_seller:0.10.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.8.0")
+        self.add_item("connection", "fetchai/soef:0.7.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.8.0")
+        self.add_item("connection", "fetchai/ledger:0.4.0")
+        self.add_item("skill", "fetchai/generic_seller:0.11.0")
         setting_path = (
             "vendor.fetchai.skills.generic_seller.models.strategy.args.is_ledger_tx"
         )
@@ -75,9 +76,9 @@ class TestGenericSkills(AEATestCaseMany):
         self.run_install()
 
         # add keys
-        self.generate_private_key(COSMOS)
+        self.generate_private_key(FETCHAI)
         self.generate_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION)
-        self.add_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE)
+        self.add_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE)
         self.add_private_key(
             COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION, connection=True
         )
@@ -85,6 +86,9 @@ class TestGenericSkills(AEATestCaseMany):
             NON_FUNDED_COSMOS_PRIVATE_KEY_1, COSMOS_PRIVATE_KEY_FILE_CONNECTION
         )
 
+        setting_path = "vendor.fetchai.connections.p2p_libp2p.config.ledger_id"
+        self.force_set_config(setting_path, COSMOS)
+
         # make runable:
         setting_path = "vendor.fetchai.skills.generic_seller.is_abstract"
         self.set_config(setting_path, False, "bool")
@@ -97,11 +101,11 @@ class TestGenericSkills(AEATestCaseMany):
 
         # prepare buyer agent
         self.set_agent_context(buyer_aea_name)
-        self.add_item("connection", "fetchai/p2p_libp2p:0.7.0")
-        self.add_item("connection", "fetchai/soef:0.6.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.7.0")
-        self.add_item("connection", "fetchai/ledger:0.3.0")
-        self.add_item("skill", "fetchai/generic_buyer:0.9.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.8.0")
+        self.add_item("connection", "fetchai/soef:0.7.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.8.0")
+        self.add_item("connection", "fetchai/ledger:0.4.0")
+        self.add_item("skill", "fetchai/generic_buyer:0.10.0")
         setting_path = (
             "vendor.fetchai.skills.generic_buyer.models.strategy.args.is_ledger_tx"
         )
@@ -111,9 +115,9 @@ class TestGenericSkills(AEATestCaseMany):
         self.run_install()
 
         # add keys
-        self.generate_private_key(COSMOS)
+        self.generate_private_key(FETCHAI)
         self.generate_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION)
-        self.add_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE)
+        self.add_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE)
         self.add_private_key(
             COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION, connection=True
         )
@@ -121,6 +125,8 @@ class TestGenericSkills(AEATestCaseMany):
         # set p2p configs
         setting_path = "vendor.fetchai.connections.p2p_libp2p.config"
         self.force_set_config(setting_path, NON_GENESIS_CONFIG)
+        setting_path = "vendor.fetchai.connections.p2p_libp2p.config.ledger_id"
+        self.force_set_config(setting_path, COSMOS)
 
         # make runable:
         setting_path = "vendor.fetchai.skills.generic_buyer.is_abstract"
@@ -225,8 +231,8 @@ class TestGenericSkillsFetchaiLedger(AEATestCaseMany):
         self.create_agents(seller_aea_name, buyer_aea_name)
 
         default_routing = {
-            "fetchai/ledger_api:0.2.0": "fetchai/ledger:0.3.0",
-            "fetchai/oef_search:0.4.0": "fetchai/soef:0.6.0",
+            "fetchai/ledger_api:0.3.0": "fetchai/ledger:0.4.0",
+            "fetchai/oef_search:0.5.0": "fetchai/soef:0.7.0",
         }
 
         # generate random location
@@ -237,26 +243,26 @@ class TestGenericSkillsFetchaiLedger(AEATestCaseMany):
 
         # prepare seller agent
         self.set_agent_context(seller_aea_name)
-        self.add_item("connection", "fetchai/p2p_libp2p:0.7.0")
-        self.add_item("connection", "fetchai/soef:0.6.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.7.0")
-        self.add_item("connection", "fetchai/ledger:0.3.0")
-        self.add_item("skill", "fetchai/generic_seller:0.10.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.8.0")
+        self.add_item("connection", "fetchai/soef:0.7.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.8.0")
+        self.add_item("connection", "fetchai/ledger:0.4.0")
+        self.add_item("skill", "fetchai/generic_seller:0.11.0")
         setting_path = "agent.default_routing"
         self.force_set_config(setting_path, default_routing)
         self.run_install()
 
         diff = self.difference_to_fetched_agent(
-            "fetchai/generic_seller:0.7.0", seller_aea_name
+            "fetchai/generic_seller:0.8.0", seller_aea_name
         )
         assert (
             diff == []
         ), "Difference between created and fetched project for files={}".format(diff)
 
         # add keys
-        self.generate_private_key(COSMOS)
+        self.generate_private_key(FETCHAI)
         self.generate_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION)
-        self.add_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE)
+        self.add_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE)
         self.add_private_key(
             COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION, connection=True
         )
@@ -264,6 +270,9 @@ class TestGenericSkillsFetchaiLedger(AEATestCaseMany):
             NON_FUNDED_COSMOS_PRIVATE_KEY_1, COSMOS_PRIVATE_KEY_FILE_CONNECTION
         )
 
+        setting_path = "vendor.fetchai.connections.p2p_libp2p.config.ledger_id"
+        self.force_set_config(setting_path, COSMOS)
+
         # make runable:
         setting_path = "vendor.fetchai.skills.generic_seller.is_abstract"
         self.set_config(setting_path, False, "bool")
@@ -276,17 +285,17 @@ class TestGenericSkillsFetchaiLedger(AEATestCaseMany):
 
         # prepare buyer agent
         self.set_agent_context(buyer_aea_name)
-        self.add_item("connection", "fetchai/p2p_libp2p:0.7.0")
-        self.add_item("connection", "fetchai/soef:0.6.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.7.0")
-        self.add_item("connection", "fetchai/ledger:0.3.0")
-        self.add_item("skill", "fetchai/generic_buyer:0.9.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.8.0")
+        self.add_item("connection", "fetchai/soef:0.7.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.8.0")
+        self.add_item("connection", "fetchai/ledger:0.4.0")
+        self.add_item("skill", "fetchai/generic_buyer:0.10.0")
         setting_path = "agent.default_routing"
         self.force_set_config(setting_path, default_routing)
         self.run_install()
 
         diff = self.difference_to_fetched_agent(
-            "fetchai/generic_buyer:0.7.0", buyer_aea_name
+            "fetchai/generic_buyer:0.8.0", buyer_aea_name
         )
         assert (
             diff == []
@@ -296,19 +305,21 @@ class TestGenericSkillsFetchaiLedger(AEATestCaseMany):
         self.set_config(setting_path, False, "bool")
 
         # add keys
-        self.generate_private_key(COSMOS)
+        self.generate_private_key(FETCHAI)
         self.generate_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION)
-        self.add_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE)
+        self.add_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE)
         self.add_private_key(
             COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION, connection=True
         )
 
         # fund key
-        self.generate_wealth(COSMOS)
+        self.generate_wealth(FETCHAI)
 
         # set p2p configs
         setting_path = "vendor.fetchai.connections.p2p_libp2p.config"
         self.force_set_config(setting_path, NON_GENESIS_CONFIG)
+        setting_path = "vendor.fetchai.connections.p2p_libp2p.config.ledger_id"
+        self.force_set_config(setting_path, COSMOS)
 
         # replace location
         setting_path = (
